@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -406,6 +406,11 @@ int AddVector( bvptr vec )
  */
 void FreeTrace(Trptr t)
 {
+if(GLOBALS->starting_unshifted_trace == t)
+	{
+	GLOBALS->starting_unshifted_trace = NULL; /* for new "standard" clicking routines */
+	}
+
 if(GLOBALS->straces)
 	{
 	struct strace_defer_free *sd = calloc_2(1, sizeof(struct strace_defer_free));
@@ -1083,8 +1088,11 @@ UpdateTracesVisible();
 }
 
 /*
- * $Id: analyzer.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: analyzer.c,v 1.3 2008/01/02 18:17:26 gtkwave Exp $
  * $Log: analyzer.c,v $
+ * Revision 1.3  2008/01/02 18:17:26  gtkwave
+ * added standard click semantics with user_standard_clicking rc variable
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
