@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -141,6 +141,7 @@ struct Node
 			/*  a ptr to an array of histents for bsearching */
     union {
       struct fac *mvlfac; /* for use with mvlsim aets */
+      struct vlist_packer_t *mvlfac_packer_vlist;
       struct vlist_t *mvlfac_vlist;
       char *value;	/* for use when unrolling ae2 values */
     } mv; 		/* anon union is a gcc extension so use mv instead.  using this union avoids crazy casting warnings */
@@ -229,12 +230,17 @@ typedef struct TraceEnt
     int	     f_filter;		/* file filter */
     int	     p_filter;		/* process filter */
 
+    double   d_minval, d_maxval; /* cached value for when auto scaling is turned off */
+
     unsigned is_alias : 1;	/* set when it's an alias (safe to free t->name then) */
     unsigned vector : 1;	/* 1 if bit vector, 0 if node */
     unsigned shift_drag_valid : 1; /* qualifies shift_drag above */
     unsigned interactive_vector_needs_regeneration : 1; /* for interactive VCDs */
+    unsigned minmax_valid : 1;	/* for d_minval, d_maxval */
 
     unsigned int flags;		/* see def below in TraceEntFlagBits */
+    unsigned int cached_flags;	/* used for analog to determine if need to recalculate */
+
     union
       {
 	nptr    nd;		/* what makes up this trace */
@@ -247,7 +253,8 @@ enum TraceEntFlagBits
 { TR_HIGHLIGHT_B, TR_HEX_B, TR_DEC_B, TR_BIN_B, TR_OCT_B, 
   TR_RJUSTIFY_B, TR_INVERT_B, TR_REVERSE_B, TR_EXCLUDE_B,
   TR_BLANK_B, TR_SIGNED_B, TR_ASCII_B, TR_COLLAPSED_B, TR_FTRANSLATED_B, TR_PTRANSLATED_B,
-  TR_ANALOG_STEP_B, TR_ANALOG_INTERPOLATED_B, TR_ANALOG_BLANK_STRETCH_B, TR_REAL_B
+  TR_ANALOG_STEP_B, TR_ANALOG_INTERPOLATED_B, TR_ANALOG_BLANK_STRETCH_B, TR_REAL_B,
+  TR_ANALOG_FULLSCALE_B, TR_ZEROFILL_B, TR_ONEFILL_B
 };
  
 #define TR_HIGHLIGHT 		(1<<TR_HIGHLIGHT_B)
@@ -266,6 +273,9 @@ enum TraceEntFlagBits
 #define TR_ANALOG_INTERPOLATED	(1<<TR_ANALOG_INTERPOLATED_B)
 #define TR_ANALOG_BLANK_STRETCH	(1<<TR_ANALOG_BLANK_STRETCH_B)
 #define TR_REAL			(1<<TR_REAL_B)
+#define TR_ANALOG_FULLSCALE	(1<<TR_ANALOG_FULLSCALE_B)
+#define TR_ZEROFILL		(1<<TR_ZEROFILL_B)
+#define TR_ONEFILL		(1<<TR_ONEFILL_B)
 
 #define TR_NUMMASK	(TR_ASCII|TR_HEX|TR_DEC|TR_BIN|TR_OCT|TR_SIGNED|TR_REAL)
 
@@ -318,8 +328,23 @@ char *attempt_vecmatch(char *s1, char *s2);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: analyzer.h,v 1.7 2008/03/25 03:22:05 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.7  2008/03/25 03:22:05  gtkwave
+ * expanded zero fill to include also a one fill (for pre-inverted nets)
+ *
+ * Revision 1.6  2008/03/24 19:33:59  gtkwave
+ * added zero range fill feature
+ *
+ * Revision 1.5  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.4  2008/01/25 04:10:14  gtkwave
+ * added new resizing options to menu
+ *
+ * Revision 1.3  2007/12/17 03:22:44  gtkwave
+ * integration of (currently unused) vlist_packer routines
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
