@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -56,6 +56,66 @@ if(flags&TR_INVERT)
 	memcpy(xtab,xfwd,AN_COUNT);
 	}
 
+if(flags&(TR_ZEROFILL|TR_ONEFILL))
+	{
+	char whichfill = (flags&TR_ZEROFILL) ? AN_0 : AN_1;
+	int msi = 0, lsi = 0, ok = 0;
+	if((t->name)&&(nbits > 1))
+		{
+		char *lbrack = strrchr(t->name, '[');
+		if(lbrack)
+			{
+			int rc = sscanf(lbrack+1, "%d:%d", &msi, &lsi);
+			if(rc == 2)
+				{
+				if(((msi - lsi + 1) == nbits) || ((lsi - msi + 1) == nbits))
+					{
+					ok = 1;	/* to ensure sanity... */
+					}
+				}
+			}
+		}
+
+	if(ok)
+		{
+		if(msi > lsi)
+			{
+			if(lsi > 0)
+				{
+				pnt=wave_alloca(msi + 1);
+	
+				memcpy(pnt, bits, nbits);
+	
+	        		for(i=nbits;i<msi+1;i++)
+	                		{
+	                		pnt[i]=whichfill;
+	                		}
+	
+				bits = pnt;
+				nbits = msi + 1;
+				}
+			}
+			else
+			{
+			if(msi > 0)
+				{
+				pnt=wave_alloca(lsi + 1);
+				
+	        		for(i=0;i<msi;i++)
+	                		{
+	                		pnt[i]=whichfill;
+	                		}
+	
+				memcpy(pnt+i, bits, nbits);
+	
+				bits = pnt;
+				nbits = lsi + 1;
+				}
+			}
+		}
+	}
+
+
 newbuff=(char *)malloc_2(nbits+6); /* for justify */
 if(flags&TR_REVERSE)
 	{
@@ -155,11 +215,17 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			else
 			if(parse[j]==AN_X)
 				{ 
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
 				for(k=j+1;k<4;k++)
 					{
-					if(parse[k]!=AN_X) match = 0; break;
+					if(parse[k]!=AN_X) 
+						{
+						char *thisbyt = parse + i + k;
+						char *lastbyt = newbuff + 3 + nbits - 1;
+						if((lastbyt - thisbyt) >= 0) match = 0; 
+						break;
+						}
 					}
 				val = (match) ? 16 : 21; break; 
 				}
@@ -167,14 +233,23 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_Z)    
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
 				for(k=j+1;k<4;k++)
 					{
 					if(parse[k]!=AN_Z) 
 						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
+						if(parse[k]==AN_X) 
+							{
+							xover = 1;
+							}
+							else
+							{
+							char *thisbyt = parse + i + k;
+							char *lastbyt = newbuff + 3 + nbits - 1;
+							if((lastbyt - thisbyt) >= 0) match = 0; 
+							}
+						break;
 						}
 					}
 
@@ -186,14 +261,23 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_W)    
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
 				for(k=j+1;k<4;k++)
 					{
 					if(parse[k]!=AN_W) 
 						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
+						if(parse[k]==AN_X) 
+							{
+							xover = 1;
+							}
+							else
+							{
+							char *thisbyt = parse + i + k;
+							char *lastbyt = newbuff + 3 + nbits - 1;
+							if((lastbyt - thisbyt) >= 0) match = 0; 
+							}
+						break;
 						}
 					}
 
@@ -205,14 +289,23 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_U)
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
 				for(k=j+1;k<4;k++)
 					{
 					if(parse[k]!=AN_U) 
 						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
+						if(parse[k]==AN_X) 
+							{
+							xover = 1;
+							}
+							else
+							{
+							char *thisbyt = parse + i + k;
+							char *lastbyt = newbuff + 3 + nbits - 1;
+							if((lastbyt - thisbyt) >= 0) match = 0; 
+							}
+						break;
 						}
 					}
 
@@ -227,9 +320,12 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 				int k;
 				for(k=j+1;k<4;k++)
 					{
-					if(parse[k]!=AN_U) 
+					if(parse[k]!=AN_DASH) 
 						{
-						if(parse[k]==AN_X) xover = 1;
+						if(parse[k]==AN_X) 
+							{
+							xover = 1;
+							}
 						break;
 						}
 					}
@@ -568,6 +664,45 @@ if(vec)
                 }
         }
 
+if((flags&(TR_ZEROFILL|TR_ONEFILL))&&(nbits>1)&&(t->n.nd->ext->msi)&&(t->n.nd->ext->lsi))
+	{
+	char whichfill = (flags&TR_ZEROFILL) ? AN_0 : AN_1;
+
+	if(t->n.nd->ext->msi > t->n.nd->ext->lsi)
+		{
+		if(t->n.nd->ext->lsi > 0)
+			{
+			pnt=wave_alloca(t->n.nd->ext->msi + 1);
+
+			memcpy(pnt, bits, nbits);
+
+        		for(i=nbits;i<t->n.nd->ext->msi+1;i++)
+                		{
+                		pnt[i]=whichfill;
+                		}
+
+			bits = pnt;
+			nbits = t->n.nd->ext->msi + 1;
+			}
+		}
+		else
+		{
+		if(t->n.nd->ext->msi > 0)
+			{
+			pnt=wave_alloca(t->n.nd->ext->lsi + 1);
+			
+        		for(i=0;i<t->n.nd->ext->msi;i++)
+                		{
+                		pnt[i]=whichfill;
+                		}
+
+			memcpy(pnt+i, bits, nbits);
+
+			bits = pnt;
+			nbits = t->n.nd->ext->lsi + 1;
+			}
+		}
+	}
 
 if(flags&TR_INVERT)
 	{
@@ -675,11 +810,17 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			else
 			if(parse[j]==AN_X)
 				{ 
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
 				for(k=j+1;k<4;k++)
 					{
-					if(parse[k]!=AN_X) match = 0; break;
+                                        if(parse[k]!=AN_X)
+                                                {
+                                                char *thisbyt = parse + i + k;
+                                                char *lastbyt = newbuff + 3 + nbits - 1;
+                                                if((lastbyt - thisbyt) >= 0) match = 0;
+                                                break;
+                                                }
 					}
 				val = (match) ? 16 : 21; break; 
 				}
@@ -687,16 +828,25 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_Z)    
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
-				for(k=j+1;k<4;k++)
-					{
-					if(parse[k]!=AN_Z) 
-						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
-						}
-					}
+                                for(k=j+1;k<4;k++)
+                                        {
+                                        if(parse[k]!=AN_Z)
+                                                {
+                                                if(parse[k]==AN_X)
+                                                        {
+                                                        xover = 1;
+                                                        }
+                                                        else
+                                                        {
+                                                        char *thisbyt = parse + i + k;
+                                                        char *lastbyt = newbuff + 3 + nbits - 1;
+                                                        if((lastbyt - thisbyt) >= 0) match = 0;
+                                                        }
+                                                break;
+                                                }
+                                        }
 
 				if(xover) val = 21;
 				else val = (match) ? 17 : 22; 
@@ -706,16 +856,25 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_W)    
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
-				for(k=j+1;k<4;k++)
-					{
-					if(parse[k]!=AN_W) 
-						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
-						}
-					}
+                                for(k=j+1;k<4;k++)
+                                        {
+                                        if(parse[k]!=AN_W)
+                                                {
+                                                if(parse[k]==AN_X)
+                                                        {
+                                                        xover = 1;
+                                                        }
+                                                        else
+                                                        {
+                                                        char *thisbyt = parse + i + k;   
+                                                        char *lastbyt = newbuff + 3 + nbits - 1;
+                                                        if((lastbyt - thisbyt) >= 0) match = 0;
+                                                        }
+                                                break;
+                                                }
+                                        }
 
 				if(xover) val = 21;
 				else val = (match) ? 18 : 23; 
@@ -725,16 +884,25 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 			if(parse[j]==AN_U)
 				{ 
 				int xover = 0;
-				int match = (j==0);
+				int match = (j==0) || ((parse + i + j) == (newbuff + 3));
 				int k;
-				for(k=j+1;k<4;k++)
-					{
-					if(parse[k]!=AN_U) 
-						{
-						if(parse[k]==AN_X) xover = 1;
-						match = 0; break;
-						}
-					}
+                                for(k=j+1;k<4;k++)
+                                        {
+                                        if(parse[k]!=AN_U)
+                                                {
+                                                if(parse[k]==AN_X)
+                                                        {
+                                                        xover = 1;
+                                                        }
+                                                        else
+                                                        {
+                                                        char *thisbyt = parse + i + k;   
+                                                        char *lastbyt = newbuff + 3 + nbits - 1;
+                                                        if((lastbyt - thisbyt) >= 0) match = 0;
+                                                        }
+                                                break;
+                                                }
+                                        }
 
 				if(xover) val = 21;
 				else val = (match) ? 19 : 24; 
@@ -745,14 +913,17 @@ else if((flags&TR_HEX)||((flags&(TR_DEC|TR_SIGNED))&&(nbits>64)))
 				{ 
 				int xover = 0;
 				int k;
-				for(k=j+1;k<4;k++)
-					{
-					if(parse[k]!=AN_U) 
-						{
-						if(parse[k]==AN_X) xover = 1;
-						break;
-						}
-					}
+                                for(k=j+1;k<4;k++)
+                                        {
+                                        if(parse[k]!=AN_DASH)
+                                                {  
+                                                if(parse[k]==AN_X)
+                                                        {
+                                                        xover = 1;
+                                                        }
+                                                break;
+                                                }
+                                        }
 
 				if(xover) val = 21;
 				else val = 20;
@@ -1355,8 +1526,20 @@ return(retval);
 }
 
 /*
- * $Id: baseconvert.c,v 1.3 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: baseconvert.c,v 1.7 2008/03/25 03:22:06 gtkwave Exp $
  * $Log: baseconvert.c,v $
+ * Revision 1.7  2008/03/25 03:22:06  gtkwave
+ * expanded zero fill to include also a one fill (for pre-inverted nets)
+ *
+ * Revision 1.6  2008/03/24 19:33:59  gtkwave
+ * added zero range fill feature
+ *
+ * Revision 1.5  2008/02/24 00:26:26  gtkwave
+ * added improved x vs X handling for hptrs (was only vptrs in prev patch)
+ *
+ * Revision 1.4  2008/02/21 03:53:39  gtkwave
+ * improved x vs X (z vs Z, etc) handling
+ *
  * Revision 1.3  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
