@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -59,6 +59,25 @@ return(GLOBALS->max_compare_pos_tc_bsearch_c_1-GLOBALS->timearray);
 
 /*****************************************************************************************/
 
+int bsearch_aetinfo_timechain(TimeType key)
+{
+void *bsearch_dummy_rv;
+
+GLOBALS->max_compare_time_tc_bsearch_c_1=-2; GLOBALS->max_compare_pos_tc_bsearch_c_1=NULL; 
+
+if(!GLOBALS->ae2_time_xlate) return(-1);
+
+bsearch_dummy_rv = bsearch(&key, GLOBALS->ae2_time_xlate, GLOBALS->ae2_end_cyc - GLOBALS->ae2_start_cyc + 1, sizeof(TimeType), compar_timechain);
+if(!GLOBALS->max_compare_pos_tc_bsearch_c_1)
+	{
+	GLOBALS->max_compare_pos_tc_bsearch_c_1=GLOBALS->ae2_time_xlate; /* aix bsearch fix */
+	}
+
+return(GLOBALS->max_compare_pos_tc_bsearch_c_1-GLOBALS->ae2_time_xlate);
+}
+
+/*****************************************************************************************/
+
 static int compar_histent(const void *s1, const void *s2)
 {
 TimeType key, obj, delta;
@@ -158,7 +177,7 @@ vcache[0]=*str;
 vcache[1]=*(str+1);
 *str='+';
 *(str+1)=0;
-obj=gdk_string_measure(GLOBALS->wavefont,GLOBALS->trunc_asciibase_bsearch_c_1);
+obj=font_engine_string_measure(GLOBALS->wavefont,GLOBALS->trunc_asciibase_bsearch_c_1);
 *str=vcache[0];
 *(str+1)=vcache[1];
 
@@ -242,8 +261,17 @@ if(rc) return(*rc); else return(NULL);
 }
 
 /*
- * $Id: bsearch.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: bsearch.c,v 1.5 2008/02/19 22:56:11 gtkwave Exp $
  * $Log: bsearch.c,v $
+ * Revision 1.5  2008/02/19 22:56:11  gtkwave
+ * rtlbrowse update to handle aet time substitutions
+ *
+ * Revision 1.4  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.3  2008/02/08 02:26:36  gtkwave
+ * anti-aliased font support add
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
