@@ -21,7 +21,7 @@ struct vlist_t *v;
 char *pnt;
 int i, ch;
 
-v = vlist_create(sizeof(char), 0);
+v = vlist_create(sizeof(char));
 
 for(;;)
 	{
@@ -89,8 +89,11 @@ return(s);
 }
 
 /*
- * $Id: fgetdynamic.c,v 1.2 2007/08/26 21:35:40 gtkwave Exp $
+ * $Id: fgetdynamic.c,v 1.3 2007/12/06 04:16:20 gtkwave Exp $
  * $Log: fgetdynamic.c,v $
+ * Revision 1.3  2007/12/06 04:16:20  gtkwave
+ * removed non-growable vlists
+ *
  * Revision 1.2  2007/08/26 21:35:40  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
