@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2006.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -84,7 +84,7 @@ gtk_widget_show(GLOBALS->fs_file_c_1);
 
 void fileselbox(char *title, char **filesel_path, GtkSignalFunc ok_func, GtkSignalFunc notok_func, char *pattn, int is_writemode)
 {
-
+int can_set_filename = 0;
 #if GTK_CHECK_VERSION(2,4,0)
 GtkWidget *pFileChoose;
 GtkWidget *pWindowMain;
@@ -131,10 +131,14 @@ if(*GLOBALS->fileselbox_text && (!g_path_is_absolute(*GLOBALS->fileselbox_text))
 #ifdef __linux__
 	char *can = canonicalize_file_name(*GLOBALS->fileselbox_text);
 
-	if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
-        *GLOBALS->fileselbox_text=(char *)malloc_2(strlen(can)+1);
-        strcpy(*GLOBALS->fileselbox_text, can);
-	free(can);
+	if(can)
+		{
+		if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
+	        *GLOBALS->fileselbox_text=(char *)malloc_2(strlen(can)+1);
+	        strcpy(*GLOBALS->fileselbox_text, can);
+		free(can);
+		can_set_filename = 1;
+		}
 
 #else
 #if defined __USE_BSD || defined __USE_XOPEN_EXTENDED || defined __CYGWIN__ || defined HAVE_REALPATH
@@ -146,6 +150,7 @@ if(*GLOBALS->fileselbox_text && (!g_path_is_absolute(*GLOBALS->fileselbox_text))
 	        *GLOBALS->fileselbox_text=(char *)malloc_2(strlen(can)+1);
 	        strcpy(*GLOBALS->fileselbox_text, can);
 		free(can);
+		can_set_filename = 1;
 		}
 #else
 #if __GNUC__
@@ -166,6 +171,10 @@ if(is_writemode)
 	        GTK_STOCK_SAVE,
 	        GTK_RESPONSE_ACCEPT,
 	        NULL);
+
+#if GTK_CHECK_VERSION(2,8,0)
+	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER (pFileChoose), TRUE);
+#endif
 	}
 	else
 	{
@@ -180,7 +189,7 @@ if(is_writemode)
 	        NULL);
 	}
 
-if(*filesel_path) gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pFileChoose), *filesel_path);
+if((can_set_filename) && (*filesel_path)) gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pFileChoose), *filesel_path);
 
 if(pattn)
 	{
@@ -189,6 +198,8 @@ if(pattn)
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(pFileChoose), filter);
 	}
 
+gtk_dialog_set_default_response(GTK_DIALOG(pFileChoose), GTK_RESPONSE_ACCEPT);
+
 gtk_object_set_data(GTK_OBJECT(pFileChoose), "FileChooseWindow", pFileChoose);
 gtk_container_set_border_width(GTK_CONTAINER(pFileChoose), 10);
 gtk_window_set_position(GTK_WINDOW(pFileChoose), GTK_WIN_POS_CENTER);
@@ -266,8 +277,23 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 }
 
 /*
- * $Id: file.c,v 1.4 2007/09/12 17:26:44 gtkwave Exp $
+ * $Id: file.c,v 1.9 2008/02/27 16:23:00 gtkwave Exp $
  * $Log: file.c,v $
+ * Revision 1.9  2008/02/27 16:23:00  gtkwave
+ * fixed potential file chooser crash
+ *
+ * Revision 1.8  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.7  2008/01/28 23:08:50  gtkwave
+ * added infinite scaling define in currenttime.h
+ *
+ * Revision 1.6  2008/01/28 21:47:06  gtkwave
+ * gtk_dialog_set_default_response added so pressing ok is not needed
+ *
+ * Revision 1.5  2008/01/28 20:07:45  gtkwave
+ * added overwrite confirm save on file chooser
+ *
  * Revision 1.4  2007/09/12 17:26:44  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
