@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007.
+ * Copyright (c) Kermin Elliott Fleming 2007-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,10 +41,21 @@
 #include "vzt.h"
 #include "wavealloca.h"
 
+#include "lxt2_read.h"
+#include "vzt_read.h"
+
 #ifdef __MINGW32__
 #define sleep(x) Sleep(x)
 #endif
 
+#if !defined __MINGW32__ && !defined _MSC_VER
+#include <unistd.h>
+#include <sys/mman.h>
+#else
+#include <windows.h>
+#include <io.h>
+#endif
+
 
 struct Global *GLOBALS = NULL;
 
@@ -59,6 +70,13 @@ NULL, /* ae2_lx2_table */
 NULL, /* ae2_f */
 NULL, /* ae2 */
 NULL, /* ae2_fr */
+NULL, /* ae2_info_f */
+NULL, /* ae2_info */
+NULL, /* ae2_time_xlate */
+LLDescriptor(0), /* ae2_start_cyc */
+LLDescriptor(0), /* ae2_end_cyc */
+LLDescriptor(0), /* ae2_start_limit_cyc */
+LLDescriptor(0), /* ae2_end_limit_cyc */
 NULL, /* ae2_process_mask */
 0, /* ae2_msg_suppress */
 NULL, /* ae2_regex_head */
@@ -212,6 +230,14 @@ NULL, /* fileselbox_text 87 */
  */
 NULL, /* fontname_signals 90 */
 NULL, /* fontname_waves 91 */
+#if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN) && GTK_CHECK_VERSION(2,8,0)
+NULL, /* fonts_renderer */
+NULL, /* fonts_gc */
+NULL, /* fonts_screen */
+NULL, /* fonts_context */
+NULL, /* fonts_layout */
+#endif
+1, /* use_pango_fonts */
 
 
 /*
@@ -279,6 +305,7 @@ NULL, /* treechain_hiersearch_c_1 130 */
 /* 
  * logfile.c
  */
+NULL, /* logfiles */
 NULL, /* fontname_logfile 133 */
 NULL, /* font_logfile_c_1 134 */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -399,8 +426,8 @@ NULL, /* expanderwindow 205 */
 0, /* disable_window_manager 206 */
 1, /* paned_pack_semantics 207 */
 0, /* zoom_was_explicitly_set 208 */
-820, /* initial_window_x 209 */
-400, /* initial_window_y */
+1000, /* initial_window_x 209 */
+600, /* initial_window_y */
 -1, /* initial_window_width */
 -1, /* initial_window_height 210 */
 0, /* xy_ignore_main_c_1 211 */
@@ -423,7 +450,11 @@ NULL, /* expanderwindow 205 */
 0, /* socket_xid 224 */
 0, /* disable_menus 225 */
 NULL, /* ftext_main_main_c_1 226 */
-
+#ifdef WAVE_USE_GTK2
+1, /* use_toolbutton_interface */
+#else
+0, /* use_toolbutton_interface */
+#endif
 
 /*
  * markerbox.c
@@ -455,6 +486,7 @@ NULL, /* filesel_lxt_writesave 250 */
 0, /* lock_menu_c_1 251 */
 0, /* lock_menu_c_2 252 */
 NULL, /* buf_menu_c_1 253 128 */
+NULL, /* signal_popup_menu */
 
 /*
  * mouseover.c
@@ -625,7 +657,14 @@ NULL, /* signal_hslider 379 */
 NULL, /* cachedtrace 382 */
 NULL, /* shift_click_trace 383 */
 0, /* trtarget_signalwindow_c_1 384 */
-
+NULL, /* starting_unshifted_trace */
+1, /* use_standard_clicking */
+0, /* std_collapse_pressed */
+0, /* std_dnd_tgt_on_signalarea */
+0, /* std_dnd_tgt_on_wavearea */
+0, /* signalarea_has_focus */
+NULL, /* signalarea_event_box */
+0, /* keypress_handler_id */
 
 /*
  * simplereq.c
@@ -752,6 +791,9 @@ NULL, /* void (*cleanup_treesearch_gtk1_c)(); */
 /*
  * treesearch_gtk2.c
  */
+0, /* tree_dnd_begin */
+0, /* tree_dnd_requested */
+1, /* do_dynamic_treefilter */
 NULL, /* treesearch_gtk2_window_vbox */
 NULL, /* selected_hierarchy_name */
 NULL, /* gtk2_tree_frame */
@@ -779,7 +821,8 @@ NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* pre_import_treesearch_gtk2_c_1 469 */
 {0,0,0,NULL,NULL,NULL,0}, /* tcache_treesearch_gtk2_c_2 470 */
 0, /* dnd_tgt_on_signalarea_treesearch_gtk2_c_1 471 */
-
+0, /* dnd_tgt_on_wavearea_treesearch_gtk2_c_1 */
+NULL, /* dnd_sigview */
 
 /*
  * vcd.c
@@ -927,6 +970,10 @@ NULL, /* nhold_vcd_saver_c_1 582 */
 /*
  * vlist.c
  */
+0, /* vlist_spill_to_disk */
+0, /* vlist_prepack */
+NULL, /* vlist_handle */
+0, /* vlist_bytes_written */
 4, /* vlist_compression_depth 583 */
 
 
@@ -976,7 +1023,7 @@ NULL, /* blackout_regions 606 */
 2.0, /* zoombase 612 */
 NULL, /* topmost_trace 613 */
 1, /* waveheight 614 */
-0, /* wavecrosspiec */
+0, /* wavecrosspiece */
 1, /* wavewidth 615 */
 NULL, /* wavefont 616 */
 NULL, /* wavefont_smaller 617 */
@@ -1021,7 +1068,36 @@ NULL, /* gc_mdgray 654 */
 NULL, /* gc_dkgray 655 */
 NULL, /* gc_dkblue 656 */
 0, /* fill_in_smaller_rgb_areas_wavewindow_c_1 659 */
-
+-1, /* prev_markertime */
+NULL, /* gccache_ltgray */
+NULL, /* gccache_normal */
+NULL, /* gccache_mdgray */
+NULL, /* gccache_dkgray */
+NULL, /* gccache_dkblue */
+NULL, /* gccache_back_wavewindow_c_1 */
+NULL, /* gccache_baseline_wavewindow_c_1 */
+NULL, /* gccache_grid_wavewindow_c_1 */
+NULL, /* gccache_time_wavewindow_c_1 */
+NULL, /* gccache_timeb_wavewindow_c_1 */
+NULL, /* gccache_value_wavewindow_c_1 */
+NULL, /* gccache_low_wavewindow_c_1 */
+NULL, /* gccache_high_wavewindow_c_1 */
+NULL, /* gccache_trans_wavewindow_c_1 */
+NULL, /* gccache_mid_wavewindow_c_1 */
+NULL, /* gccache_xfill_wavewindow_c_1 */
+NULL, /* gccache_x_wavewindow_c_1 */
+NULL, /* gccache_vbox_wavewindow_c_1 */
+NULL, /* gccache_vtrans_wavewindow_c_1 */
+NULL, /* gccache_mark_wavewindow_c_1 */
+NULL, /* gccache_umark_wavewindow_c_1 */
+NULL, /* gccache_0_wavewindow_c_1 */
+NULL, /* gccache_1_wavewindow_c_1 */
+NULL, /* gccache_ufill_wavewindow_c_1 */
+NULL, /* gccache_u_wavewindow_c_1 */
+NULL, /* gccache_wfill_wavewindow_c_1 */
+NULL, /* gccache_w_wavewindow_c_1 */
+NULL, /* gccache_dashfill_wavewindow_c_1 */
+NULL, /* gccache_dash_wavewindow_c_1 */
 
 /*
  * zoombuttons.c
@@ -1120,6 +1196,8 @@ void reload_into_new_context(void)
  char cached_ignore_savefile_size = GLOBALS->ignore_savefile_size;
  char cached_splash_disable = GLOBALS->splash_disable;
 
+ logbox_reload();
+
  /* let all GTK/X events spin through in order to keep menus from freezing open during reload */
  if(GLOBALS->text_status_c_2)
 	{
@@ -1135,7 +1213,9 @@ void reload_into_new_context(void)
  statefile = fopen(save_tmpfilename,"wb");
  if(statefile == NULL) {
    fprintf(stderr, "Failed to reload file.\n");
+#if !defined _MSC_VER && !defined __MINGW32__
    free_2(save_tmpfilename);
+#endif
    return;
  }
  if(fd_dummy >=0) close(fd_dummy);
@@ -1143,7 +1223,9 @@ void reload_into_new_context(void)
  fclose(statefile);
 
  reload_tmpfilename = strdup(save_tmpfilename);
+#if !defined _MSC_VER && !defined __MINGW32__
  free_2(save_tmpfilename);
+#endif
  
  /* save off size of tree frame if active */
 #if WAVE_USE_GTK2
@@ -1183,6 +1265,8 @@ void reload_into_new_context(void)
  new_globals->dead_context = GLOBALS->dead_context; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
 
  /* Default colors, X contexts, pixmaps, drawables, etc from signalwindow.c and wavewindow.c */
+ new_globals->signalarea_event_box = GLOBALS->signalarea_event_box;
+ new_globals->keypress_handler_id = GLOBALS->keypress_handler_id;
  new_globals->signalarea = GLOBALS->signalarea;
  new_globals->wavearea = GLOBALS->wavearea;
  new_globals->wavepixmap_wavewindow_c_1 = GLOBALS->wavepixmap_wavewindow_c_1;
@@ -1225,6 +1309,36 @@ void reload_into_new_context(void)
  new_globals->gc_dash_wavewindow_c_1 = GLOBALS->gc_dash_wavewindow_c_1;
  new_globals->made_gc_contexts_wavewindow_c_1 = GLOBALS->made_gc_contexts_wavewindow_c_1;
 
+ new_globals->gccache_ltgray = GLOBALS->gccache_ltgray;
+ new_globals->gccache_normal = GLOBALS->gccache_normal;
+ new_globals->gccache_mdgray = GLOBALS->gccache_mdgray;
+ new_globals->gccache_dkgray = GLOBALS->gccache_dkgray;
+ new_globals->gccache_dkblue = GLOBALS->gccache_dkblue;
+ new_globals->gccache_back_wavewindow_c_1 = GLOBALS->gccache_back_wavewindow_c_1;
+ new_globals->gccache_baseline_wavewindow_c_1 = GLOBALS->gccache_baseline_wavewindow_c_1;
+ new_globals->gccache_grid_wavewindow_c_1 = GLOBALS->gccache_grid_wavewindow_c_1;
+ new_globals->gccache_time_wavewindow_c_1 = GLOBALS->gccache_time_wavewindow_c_1;
+ new_globals->gccache_timeb_wavewindow_c_1 = GLOBALS->gccache_timeb_wavewindow_c_1;
+ new_globals->gccache_value_wavewindow_c_1 = GLOBALS->gccache_value_wavewindow_c_1;
+ new_globals->gccache_low_wavewindow_c_1 = GLOBALS->gccache_low_wavewindow_c_1;
+ new_globals->gccache_high_wavewindow_c_1 = GLOBALS->gccache_high_wavewindow_c_1;
+ new_globals->gccache_trans_wavewindow_c_1 = GLOBALS->gccache_trans_wavewindow_c_1;
+ new_globals->gccache_mid_wavewindow_c_1 = GLOBALS->gccache_mid_wavewindow_c_1;
+ new_globals->gccache_xfill_wavewindow_c_1 = GLOBALS->gccache_xfill_wavewindow_c_1;
+ new_globals->gccache_x_wavewindow_c_1 = GLOBALS->gccache_x_wavewindow_c_1;
+ new_globals->gccache_vbox_wavewindow_c_1 = GLOBALS->gccache_vbox_wavewindow_c_1;
+ new_globals->gccache_vtrans_wavewindow_c_1 = GLOBALS->gccache_vtrans_wavewindow_c_1;
+ new_globals->gccache_mark_wavewindow_c_1 = GLOBALS->gccache_mark_wavewindow_c_1;
+ new_globals->gccache_umark_wavewindow_c_1 = GLOBALS->gccache_umark_wavewindow_c_1;
+ new_globals->gccache_0_wavewindow_c_1 = GLOBALS->gccache_0_wavewindow_c_1;
+ new_globals->gccache_1_wavewindow_c_1 = GLOBALS->gccache_1_wavewindow_c_1;
+ new_globals->gccache_ufill_wavewindow_c_1 = GLOBALS->gccache_ufill_wavewindow_c_1;
+ new_globals->gccache_u_wavewindow_c_1 = GLOBALS->gccache_u_wavewindow_c_1;
+ new_globals->gccache_wfill_wavewindow_c_1 = GLOBALS->gccache_wfill_wavewindow_c_1;
+ new_globals->gccache_w_wavewindow_c_1 = GLOBALS->gccache_w_wavewindow_c_1;
+ new_globals->gccache_dashfill_wavewindow_c_1 = GLOBALS->gccache_dashfill_wavewindow_c_1;
+ new_globals->gccache_dash_wavewindow_c_1 = GLOBALS->gccache_dash_wavewindow_c_1;
+
  new_globals->mainwindow = GLOBALS->mainwindow;
  new_globals->signalwindow = GLOBALS->signalwindow; 
  new_globals->wavewindow = GLOBALS->wavewindow;
@@ -1234,8 +1348,6 @@ void reload_into_new_context(void)
  new_globals->signal_hslider = GLOBALS->signal_hslider;
  new_globals->wave_vslider = GLOBALS->wave_vslider;
  new_globals->wave_hslider = GLOBALS->wave_hslider;
- new_globals->signalfont = GLOBALS->signalfont;
- new_globals->wavefont = GLOBALS->wavefont;
  new_globals->max_or_marker_label_currenttime_c_1 = GLOBALS->max_or_marker_label_currenttime_c_1;
  new_globals->maxtext_currenttime_c_1 = (char *) calloc_2_into_context(new_globals,1,40);
  memcpy(new_globals->maxtext_currenttime_c_1, GLOBALS->maxtext_currenttime_c_1,40); 
@@ -1247,6 +1359,27 @@ void reload_into_new_context(void)
  new_globals->from_entry = GLOBALS->from_entry;
  new_globals->to_entry = GLOBALS->to_entry;
 
+ new_globals->fontheight = GLOBALS->fontheight;
+ new_globals->wavecrosspiece = GLOBALS->wavecrosspiece;
+
+ new_globals->signalfont = calloc_2_into_context(new_globals, 1, sizeof(struct font_engine_font_t));
+ memcpy(new_globals->signalfont, GLOBALS->signalfont, sizeof(struct font_engine_font_t));
+
+ new_globals->wavefont = calloc_2_into_context(new_globals, 1, sizeof(struct font_engine_font_t));
+ memcpy(new_globals->wavefont, GLOBALS->wavefont, sizeof(struct font_engine_font_t));
+
+ new_globals->wavefont_smaller = calloc_2_into_context(new_globals, 1, sizeof(struct font_engine_font_t));
+ memcpy(new_globals->wavefont_smaller, GLOBALS->wavefont_smaller, sizeof(struct font_engine_font_t));
+
+#if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN) && GTK_CHECK_VERSION(2,8,0)
+ new_globals->fonts_renderer = GLOBALS->fonts_renderer;
+ new_globals->fonts_gc = GLOBALS->fonts_gc;
+ new_globals->fonts_screen = GLOBALS->fonts_screen;
+ new_globals->fonts_context = GLOBALS->fonts_context;
+ new_globals->fonts_layout = GLOBALS->fonts_layout;
+#endif
+ new_globals->use_pango_fonts = GLOBALS->use_pango_fonts;
+
  /* busy.c */
  new_globals->busycursor_busy_c_1 = GLOBALS->busycursor_busy_c_1;
  new_globals->busy_busy_c_1 = GLOBALS->busy_busy_c_1;
@@ -1268,6 +1401,7 @@ void reload_into_new_context(void)
 
  /* rc.c */
  new_globals->context_tabposition = GLOBALS->context_tabposition;
+ new_globals->use_standard_clicking = GLOBALS->use_standard_clicking;
 
  new_globals->ignore_savefile_pos = 1; /* to keep window from resizing/jumping */
  new_globals->ignore_savefile_size = 1; /* to keep window from resizing/jumping */
@@ -1341,6 +1475,8 @@ void reload_into_new_context(void)
  new_globals->vcd_preserve_glitches = GLOBALS->vcd_preserve_glitches;
  new_globals->vcd_warning_filesize = GLOBALS->vcd_warning_filesize;
  new_globals->vector_padding = GLOBALS->vector_padding;
+ new_globals->vlist_prepack = GLOBALS->vlist_prepack;
+ new_globals->vlist_spill_to_disk = GLOBALS->vlist_spill_to_disk;
  new_globals->vlist_compression_depth = GLOBALS->vlist_compression_depth;
  new_globals->wave_scrolling = GLOBALS->wave_scrolling;
  new_globals->do_zoom_center = GLOBALS->do_zoom_center;
@@ -1352,20 +1488,31 @@ void reload_into_new_context(void)
  new_globals->page_divisor = GLOBALS->page_divisor;
  new_globals->ps_maxveclen = GLOBALS->ps_maxveclen;
  new_globals->vector_padding = GLOBALS->vector_padding;
- new_globals->vlist_compression_depth = GLOBALS->vlist_compression_depth;
  new_globals->zoombase = GLOBALS->zoombase;
  new_globals->splash_disable = 1; /* to disable splash for reload */
 
+ new_globals->logfiles = GLOBALS->logfiles; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
+
  strcpy2_into_new_context(new_globals, &new_globals->fontname_logfile, &GLOBALS->fontname_logfile);
  strcpy2_into_new_context(new_globals, &new_globals->fontname_signals, &GLOBALS->fontname_signals); 
  strcpy2_into_new_context(new_globals, &new_globals->fontname_waves, &GLOBALS->fontname_waves);
 
+ /* vlist.c */
+ if(GLOBALS->vlist_handle)
+	{
+	vlist_kill_spillfile();
+	vlist_init_spillfile();
+	new_globals->vlist_handle = GLOBALS->vlist_handle;
+	new_globals->vlist_bytes_written = GLOBALS->vlist_bytes_written;
+	}
+
  /* lxt2.c / vzt.c / ae2.c */
  strcpy2_into_new_context(new_globals, &new_globals->skip_start, &GLOBALS->skip_start);
  strcpy2_into_new_context(new_globals, &new_globals->skip_end, &GLOBALS->skip_end);
  strcpy2_into_new_context(new_globals, &new_globals->indirect_fname, &GLOBALS->indirect_fname);
 
  /* main.c */
+ new_globals->use_toolbutton_interface = GLOBALS->use_toolbutton_interface;
  new_globals->optimize_vcd = GLOBALS->optimize_vcd;
  strcpy2_into_new_context(new_globals, &new_globals->winname, &GLOBALS->winname); /* for page swapping */
 
@@ -1374,6 +1521,7 @@ void reload_into_new_context(void)
  new_globals->item_factory_menu_c_1 = GLOBALS->item_factory_menu_c_1;
  strcpy2_into_new_context(new_globals, &new_globals->filesel_writesave, &GLOBALS->filesel_writesave);
  new_globals->save_success_menu_c_1 = GLOBALS->save_success_menu_c_1; 
+ new_globals->signal_popup_menu = GLOBALS->signal_popup_menu;
 
  /* status.c */
  new_globals->text_status_c_2 = GLOBALS->text_status_c_2;
@@ -1382,8 +1530,10 @@ void reload_into_new_context(void)
 #endif
 
  /* treesearch_gtk2.c */
+ new_globals->do_dynamic_treefilter = GLOBALS->do_dynamic_treefilter;
  new_globals->treesearch_gtk2_window_vbox = GLOBALS->treesearch_gtk2_window_vbox;
  new_globals->window_treesearch_gtk2_c_12 = GLOBALS->window_treesearch_gtk2_c_12;
+ new_globals->dnd_sigview = GLOBALS->dnd_sigview;
 
  strcpy2_into_new_context(new_globals, &new_globals->filter_str_treesearch_gtk2_c_1, &GLOBALS->filter_str_treesearch_gtk2_c_1);
  strcpy2_into_new_context(new_globals, &new_globals->selected_hierarchy_name, &GLOBALS->selected_hierarchy_name);
@@ -1437,6 +1587,7 @@ void reload_into_new_context(void)
    case AE2_FILE: 
 #ifdef AET2_IS_PRESENT
 	ae2_read_end(GLOBALS->ae2); fclose(GLOBALS->ae2_f); 
+	if(GLOBALS->ae2_info) { ae2_read_end(GLOBALS->ae2_info); fclose(GLOBALS->ae2_info_f); } 
 #endif
 	break;
   
@@ -1559,15 +1710,16 @@ void reload_into_new_context(void)
  free(GLOBALS);
 
  /* Set the GLOBALS pointer to the newly allocated struct. */
- GLOBALS = new_globals;
+ set_GLOBALS(new_globals);
  *(GLOBALS->gtk_context_bridge_ptr) = GLOBALS;
 
 
  /* Initialize new variables */
  GLOBALS->sym=(struct symbol **)calloc_2(SYMPRIME,sizeof(struct symbol *));
 
+ init_filetrans_data();
  init_proctrans_data();
- load_all_fonts();
+ /* load_all_fonts(); */
 
  /* attempt to reload file and recover on loader errors until successful */
  for(;;)
@@ -1653,7 +1805,8 @@ void reload_into_new_context(void)
 				{
 				free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
 				if(GLOBALS->vcd_handle_vcd_c_1) { fclose(GLOBALS->vcd_handle_vcd_c_1); GLOBALS->vcd_handle_vcd_c_1 = NULL; }
-				if(GLOBALS->vcd_handle_vcd_recoder_c_2) { fclose(GLOBALS->vcd_handle_vcd_recoder_c_2); GLOBALS->vcd_handle_vcd_recoder_c_2 =NULL; }
+				if(GLOBALS->vcd_handle_vcd_recoder_c_2) { fclose(GLOBALS->vcd_handle_vcd_recoder_c_2); GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL; }
+				if(GLOBALS->vlist_handle) { fclose(GLOBALS->vlist_handle); GLOBALS->vlist_handle = NULL; }
 				if(GLOBALS->mm_lxt_mmap_addr)
 					{                        
 					munmap(GLOBALS->mm_lxt_mmap_addr, GLOBALS->mm_lxt_mmap_len); 
@@ -1736,6 +1889,15 @@ void reload_into_new_context(void)
    GLOBALS->sstpane = treeboxframe("SST", GTK_SIGNAL_FUNC(mkmenu_treesearch_cleanup));
    gtk_container_add(GTK_CONTAINER(GLOBALS->expanderwindow), GLOBALS->sstpane);
    gtk_widget_show(GLOBALS->expanderwindow);
+   if(GLOBALS->dnd_sigview)
+        {
+	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
+	}
+
+   if(GLOBALS->clist_search_c_3)
+	{
+	dnd_setup(GLOBALS->clist_search_c_3, GLOBALS->signalarea);
+	}
  }
  #endif
  #if WAVE_USE_GTK2 
@@ -1755,6 +1917,12 @@ void reload_into_new_context(void)
  /* Reload state from file */
  read_save_helper(reload_tmpfilename); 
 
+ /* again doing this here (read_save_helper does it) seems to be necessary in order to keep display in sync */
+ GLOBALS->signalwindow_width_dirty=1;
+ MaxSignalLength();
+ signalarea_configure_event(GLOBALS->signalarea, NULL);
+ wavearea_configure_event(GLOBALS->wavearea, NULL);
+
  /* unlink temp */
  unlink(reload_tmpfilename);
  free(reload_tmpfilename); /* intentional use of free(), of strdup'd string from earlier */
@@ -1815,6 +1983,7 @@ void reload_into_new_context(void)
 	/* gtk_widget_set_size_request(GLOBALS->gtk2_tree_frame, -1, tree_frame_y); */
 	}
 
+ if(GLOBALS->filter_entry) { gtk_signal_emit_by_name (GTK_OBJECT (GLOBALS->filter_entry), "activate"); }
  }
  #endif
 
@@ -1973,7 +2142,7 @@ if(gp)
 	{
 	g_curr = GLOBALS;
 
-	GLOBALS = gp;
+	set_GLOBALS(gp);
 	(*GLOBALS->dead_context)[0] = NULL;
 
 	/* remove the bridge pointer */
@@ -1986,7 +2155,7 @@ if(gp)
 	memset(GLOBALS, 0, sizeof(struct Global));
 	free(GLOBALS);
 
-	GLOBALS = g_curr;
+	set_GLOBALS(g_curr);
 	}
 }
 
@@ -2030,7 +2199,7 @@ switch(type)
 
 							/* printf("Switching to: %d %08x\n", i, GTK_WINDOW(wcmp)); */
 
-							GLOBALS = (*GLOBALS->contexts)[i];
+							set_GLOBALS((*GLOBALS->contexts)[i]);
 
 							GLOBALS->lxt_clock_compress_to_z = g_old->lxt_clock_compress_to_z;
 							GLOBALS->autoname_bundles = g_old->autoname_bundles;
@@ -2088,7 +2257,7 @@ if(GLOBALS->gtk_context_bridge_ptr != w)
 		GLOBALS->gtk_context_bridge_ptr,w, (*GLOBALS->gtk_context_bridge_ptr)->this_context_page, watch->this_context_page);
 #endif
 
-	GLOBALS = watch;
+	set_GLOBALS(watch);
 	}
 
 return(0);
@@ -2105,7 +2274,7 @@ printf(">>>\t%d\n", d);
 return(0);
 }
 
-gulong gtkwave_signal_connect_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, int line)
+gulong gtkwave_signal_connect_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line)
 {
 gulong rc;
 
@@ -2122,7 +2291,7 @@ return(rc);
 }
 
 
-gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, int line)
+gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line)
 {
 gulong rc;
 
@@ -2137,3 +2306,14 @@ rc = gtk_signal_connect_object(object, name, func, data);
 
 return(rc);
 }
+
+
+void set_GLOBALS_x(struct Global *g, const char *file, int line)
+{
+if(line)
+	{
+	printf("Globals old %p -> new %p (%s: %d)\n", GLOBALS, g, file, line);
+	}
+
+GLOBALS = g;
+}
