@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007.
+ * Copyright (c) Kermin Elliott Fleming 2007-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 #include"currenttime.h"
 #include"debug.h"
 #include"fgetdynamic.h"
+#include"fonts.h"
 #include"ghw.h"
 #include"globals.h"
 #include"gnu_regex.h"
@@ -63,6 +64,13 @@ struct lx2_entry **ae2_lx2_table;
 FILE *ae2_f;
 AE2_HANDLE *ae2;
 FACREF *ae2_fr;
+FILE *ae2_info_f;
+AE2_HANDLE *ae2_info;
+TimeType *ae2_time_xlate;
+TimeType ae2_start_cyc;
+TimeType ae2_end_cyc;
+TimeType ae2_start_limit_cyc;
+TimeType ae2_end_limit_cyc;
 char *ae2_process_mask;
 char ae2_msg_suppress;
 struct regex_links *ae2_regex_head;
@@ -217,6 +225,14 @@ void (*bad_cleanup_file_c_1)(); /* from file.c 91 */
  */ 
 char *fontname_signals; /* from fonts.c 92 */
 char *fontname_waves; /* from fonts.c 93 */
+#if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN) && GTK_CHECK_VERSION(2,8,0)
+PangoRenderer *fonts_renderer;
+GdkGC *fonts_gc;
+GdkScreen *fonts_screen;
+PangoContext *fonts_context;
+PangoLayout *fonts_layout;
+#endif
+char use_pango_fonts;
 
 
 /*
@@ -286,6 +302,7 @@ int is_active_hiersearch_c_1; /* from hiersearch.c 135 */
 /*
  * logfile.c
  */
+void **logfiles;
 char *fontname_logfile; /* from logfile.c 137 */
 GdkFont *font_logfile_c_1; /* from logfile.c 138 */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -429,6 +446,7 @@ int sst_expanded; /* from main.c 240 */
 unsigned int socket_xid; /* from main.c 241 */
 int disable_menus; /* from main.c 242 */
 char *ftext_main_main_c_1; /* from main.c 243 */
+char use_toolbutton_interface; /* from main.c */
 
 
 /*
@@ -461,6 +479,7 @@ char *filesel_lxt_writesave; /* from menu.c 267 */
 int lock_menu_c_1; /* from menu.c 268 */
 int lock_menu_c_2; /* from menu.c 269 */
 char *buf_menu_c_1; /* from menu.c 270 */
+GtkWidget *signal_popup_menu; /* from menu.c */
 
 
 /*
@@ -616,7 +635,7 @@ unsigned int flags_showchange_c_1; /* from showchange.c 395 */
  * signalwindow.c
  */
 GtkWidget *signalarea; /* from signalwindow.c 396 */
-GdkFont *signalfont; /* from signalwindow.c 397 */
+struct font_engine_font_t *signalfont; /* from signalwindow.c 397 */
 GdkDrawable *signalpixmap; /* from signalwindow.c 398 */
 int max_signal_name_pixel_width; /* from signalwindow.c 399 */
 int signal_pixmap_width; /* from signalwindow.c 400 */
@@ -632,6 +651,14 @@ int cachedwhich_signalwindow_c_1; /* from signalwindow.c 409 */
 struct TraceEnt *cachedtrace; /* from signalwindow.c 410 */
 struct TraceEnt *shift_click_trace; /* from signalwindow.c 411 */
 int trtarget_signalwindow_c_1; /* from signalwindow.c 412 */
+Trptr starting_unshifted_trace; /* from signalwindow.c */
+unsigned char use_standard_clicking; /* from signalwindow.c */
+unsigned char std_collapse_pressed; /* from signalwindow.c */
+unsigned char std_dnd_tgt_on_signalarea; /* from signalwindow.c */
+unsigned char std_dnd_tgt_on_wavearea; /* from signalwindow.c */
+unsigned char signalarea_has_focus; /* from signalwindow.c */
+GtkWidget *signalarea_event_box; /* from signalwindow.c */
+gint keypress_handler_id; /* from signalwindow.c */
 
 
 /*
@@ -759,6 +786,9 @@ void (*cleanup_treesearch_gtk1_c)(); /* ...end of manual adds */
 /*
  * treesearch_gtk2.c
  */
+char tree_dnd_begin; /* from treesearch_gtk2.c */
+char tree_dnd_requested; /* from treesearch_gtk2.c */
+char do_dynamic_treefilter; /* from treesearch_gtk2.c */
 GtkWidget *treesearch_gtk2_window_vbox; /* from treesearch_gtk2.c */
 char *selected_hierarchy_name; /* from treesearch_gtk2.c */
 GtkWidget *gtk2_tree_frame; /* from treesearch_gtk2.c */
@@ -785,8 +815,9 @@ char bundle_direction_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 497 */
 void (*cleanup_treesearch_gtk2_c_8)(); /* from treesearch_gtk2.c 498 */
 int pre_import_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 499 */
 Traces tcache_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 500 */
-int dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 501 */
-
+unsigned char dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 501 */
+unsigned char dnd_tgt_on_wavearea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c */
+GtkWidget *dnd_sigview; /* from treesearch_gtk2.c */
 
 /*
  * vcd.c
@@ -803,7 +834,7 @@ char vcd_preserve_glitches; /* from vcd.c 509 */
 FILE *vcd_save_handle; /* from vcd.c 510 */
 FILE *vcd_handle_vcd_c_1; /* from vcd.c 511 */
 char vcd_is_compressed_vcd_c_1; /* from vcd.c 512 */
-int vcdbyteno_vcd_c_1; /* from vcd.c 513 */
+off_t vcdbyteno_vcd_c_1; /* from vcd.c 513 */
 int error_count_vcd_c_1; /* from vcd.c 514 */
 int header_over_vcd_c_1; /* from vcd.c 515 */
 int dumping_off_vcd_c_1; /* from vcd.c 516 */
@@ -838,7 +869,7 @@ struct queuedevent *queuedevents_vcd_c_1; /* from vcd.c 545 */
 unsigned int vcd_minid_vcd_c_1; /* from vcd.c 546 */
 unsigned int vcd_maxid_vcd_c_1; /* from vcd.c 547 */
 int err_vcd_c_1; /* from vcd.c 548 */
-int vcd_fsiz_vcd_c_1; /* from vcd.c 549 */
+off_t vcd_fsiz_vcd_c_1; /* from vcd.c 549 */
 char *varsplit_vcd_c_1; /* from vcd.c 550 */
 char *vsplitcurr_vcd_c_1; /* from vcd.c 551 */
 int var_prevch_vcd_c_1; /* from vcd.c 552 */
@@ -847,7 +878,7 @@ int var_prevch_vcd_c_1; /* from vcd.c 552 */
 /*
  * vcd_partial.c
  */
-int vcdbyteno_vcd_partial_c_2; /* from vcd_partial.c 555 */
+off_t vcdbyteno_vcd_partial_c_2; /* from vcd_partial.c 555 */
 int error_count_vcd_partial_c_2; /* from vcd_partial.c 556 */
 int header_over_vcd_partial_c_2; /* from vcd_partial.c 557 */
 int dumping_off_vcd_partial_c_2; /* from vcd_partial.c 558 */
@@ -890,7 +921,7 @@ struct vlist_t *time_vlist_vcd_recoder_c_1; /* from vcd_recoder.c 593 */
 unsigned int time_vlist_count_vcd_recoder_c_1; /* from vcd_recoder.c 594 */
 FILE *vcd_handle_vcd_recoder_c_2; /* from vcd_recoder.c 595 */
 char vcd_is_compressed_vcd_recoder_c_2; /* from vcd_recoder.c 596 */
-int vcdbyteno_vcd_recoder_c_3; /* from vcd_recoder.c 597 */
+off_t vcdbyteno_vcd_recoder_c_3; /* from vcd_recoder.c 597 */
 int error_count_vcd_recoder_c_3; /* from vcd_recoder.c 598 */
 int header_over_vcd_recoder_c_3; /* from vcd_recoder.c 599 */
 int dumping_off_vcd_recoder_c_3; /* from vcd_recoder.c 600 */
@@ -916,7 +947,7 @@ int numsyms_vcd_recoder_c_3; /* from vcd_recoder.c 620 */
 unsigned int vcd_minid_vcd_recoder_c_3; /* from vcd_recoder.c 621 */
 unsigned int vcd_maxid_vcd_recoder_c_3; /* from vcd_recoder.c 622 */
 int err_vcd_recoder_c_3; /* from vcd_recoder.c 623 */
-int vcd_fsiz_vcd_recoder_c_2; /* from vcd_recoder.c 624 */
+off_t vcd_fsiz_vcd_recoder_c_2; /* from vcd_recoder.c 624 */
 char *varsplit_vcd_recoder_c_3; /* from vcd_recoder.c 625 */
 char *vsplitcurr_vcd_recoder_c_3; /* from vcd_recoder.c 626 */
 int var_prevch_vcd_recoder_c_3; /* from vcd_recoder.c 627 */
@@ -934,6 +965,10 @@ struct namehier *nhold_vcd_saver_c_1; /* from vcd_saver.c 633 */
 /*
  * vlist.c
  */
+char vlist_spill_to_disk;
+char vlist_prepack;
+FILE *vlist_handle;
+off_t vlist_bytes_written;
 int vlist_compression_depth; /* from vlist.c 634 */
 
 
@@ -985,8 +1020,8 @@ struct TraceEnt *topmost_trace; /* from wavewindow.c 671 */
 int waveheight; /* from wavewindow.c 672 */
 int wavecrosspiece; /* from wavewindow.c 673 */
 int wavewidth; /* from wavewindow.c 674 */
-GdkFont *wavefont; /* from wavewindow.c 675 */
-GdkFont *wavefont_smaller; /* from wavewindow.c 676 */
+struct font_engine_font_t *wavefont; /* from wavewindow.c 675 */
+struct font_engine_font_t *wavefont_smaller; /* from wavewindow.c 676 */
 GtkWidget *wavearea; /* from wavewindow.c 677 */
 GtkWidget *vscroll_wavewindow_c_1; /* from wavewindow.c 678 */
 GtkWidget *hscroll_wavewindow_c_2; /* from wavewindow.c 679 */
@@ -1028,7 +1063,36 @@ GdkGC *gc_mdgray; /* from wavewindow.c 714 */
 GdkGC *gc_dkgray; /* from wavewindow.c 715 */
 GdkGC *gc_dkblue; /* from wavewindow.c 716 */
 char fill_in_smaller_rgb_areas_wavewindow_c_1; /* from wavewindow.c 719 */
-
+TimeType prev_markertime; /* from wavewindow.c */
+GdkGC *gccache_ltgray; /* from wavewindow.c */
+GdkGC *gccache_normal; /* from wavewindow.c */
+GdkGC *gccache_mdgray; /* from wavewindow.c */
+GdkGC *gccache_dkgray; /* from wavewindow.c */
+GdkGC *gccache_dkblue; /* from wavewindow.c */
+GdkGC *gccache_back_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_baseline_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_grid_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_time_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_timeb_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_value_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_low_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_high_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_trans_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_mid_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_xfill_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_x_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_vbox_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_vtrans_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_mark_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_umark_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_0_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_1_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_ufill_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_u_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_wfill_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_w_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_dashfill_wavewindow_c_1; /* from wavewindow.c */
+GdkGC *gccache_dash_wavewindow_c_1; /* from wavewindow.c */
 
 /*
  * zoombuttons.c
@@ -1047,21 +1111,27 @@ void dead_context_sweep(void);
 void install_focus_cb(GtkWidget *w, unsigned long ptr_offset);
 
 
-gulong gtkwave_signal_connect_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, int line);
-gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, int line);
+gulong gtkwave_signal_connect_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line);
+gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line);
 
 #ifdef GTKWAVE_SIGNAL_CONNECT_DEBUG
-
 #define gtkwave_signal_connect(a,b,c,d) gtkwave_signal_connect_x(a,b,c,d,__FILE__,__LINE__)
 #define gtkwave_signal_connect_object(a,b,c,d) gtkwave_signal_connect_object_x(a,b,c,d,__FILE__,__LINE__)
-
 #else
-
 #define gtkwave_signal_connect(a,b,c,d) gtkwave_signal_connect_x(a,b,c,d,NULL,0)
 #define gtkwave_signal_connect_object(a,b,c,d) gtkwave_signal_connect_object_x(a,b,c,d,NULL,0)
-
 #endif
 
 
+void set_GLOBALS_x(struct Global *g, const char *file, int line);
+
+#ifdef GTKWAVE_GLOBALS_DEBUG
+#define set_GLOBALS(a) set_GLOBALS_x(a,__FILE__,__LINE__)
+#else
+#define set_GLOBALS(a) set_GLOBALS_x(a,NULL,0)
+#endif
+
+void logbox_reload(void);
+
 extern struct Global *GLOBALS;
 #endif
