@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999.
+ * Copyright (c) Tony Bybell 1999-2008
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,6 +28,8 @@ gtk_text_buffer_insert (GTK_TEXT_VIEW (GLOBALS->text_help_c_1)->buffer, &GLOBALS
 #else
 gtk_text_insert (GTK_TEXT (GLOBALS->text_help_c_1), NULL, &GLOBALS->text_help_c_1->style->black, NULL, str, -1);
 #endif
+
+gdk_window_raise(GLOBALS->window_help_c_2->window);
 }
 
 void help_text_bold(char *str)
@@ -38,6 +40,8 @@ gtk_text_buffer_insert_with_tags (GTK_TEXT_VIEW (GLOBALS->text_help_c_1)->buffer
 #else
 gtk_text_insert (GTK_TEXT (GLOBALS->text_help_c_1), NULL, &GLOBALS->text_help_c_1->style->fg[GTK_STATE_SELECTED], &GLOBALS->text_help_c_1->style->bg[GTK_STATE_SELECTED], str, -1);
 #endif
+
+gdk_window_raise(GLOBALS->window_help_c_2->window);
 }
 
 static void
@@ -60,11 +64,13 @@ table = gtk_table_new (1, 16, FALSE);
 * GTK_SHRINK in the y direction */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
 GLOBALS->text_help_c_1 = gtk_text_view_new ();
+gtk_text_view_set_editable (GTK_TEXT_VIEW(GLOBALS->text_help_c_1), FALSE);
 gtk_text_buffer_get_start_iter (gtk_text_view_get_buffer(GTK_TEXT_VIEW (GLOBALS->text_help_c_1)), &GLOBALS->iter_help_c_1);
 GLOBALS->bold_tag_help_c_1 = gtk_text_buffer_create_tag (GTK_TEXT_VIEW (GLOBALS->text_help_c_1)->buffer, "bold",
                                       "weight", PANGO_WEIGHT_BOLD, NULL);
 #else
 GLOBALS->text_help_c_1 = gtk_text_new (NULL, NULL);
+gtk_text_set_editable(GTK_TEXT(GLOBALS->text_help_c_1), FALSE);
 #endif
 gtk_table_attach (GTK_TABLE (table), GLOBALS->text_help_c_1, 0, 14, 0, 1,
 		      	GTK_FILL | GTK_EXPAND,
@@ -163,8 +169,11 @@ void helpbox(char *title, int width, char *default_text)
 }
 
 /*
- * $Id: help.c,v 1.4 2007/09/12 17:26:44 gtkwave Exp $
+ * $Id: help.c,v 1.5 2008/01/13 23:39:58 gtkwave Exp $
  * $Log: help.c,v $
+ * Revision 1.5  2008/01/13 23:39:58  gtkwave
+ * help window ergonomics (auto click-to-front, not-editable status set)
+ *
  * Revision 1.4  2007/09/12 17:26:44  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
