@@ -29,6 +29,8 @@
 
 #include <time.h>
 
+#include "wave_locale.h"
+
 int flat_earth = 0;
 extern void free_hier(void);
 extern char *output_hier(char *name);
@@ -379,8 +381,11 @@ return(rc);
 }
 
 /*
- * $Id: lxt2vcd.c,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: lxt2vcd.c,v 1.1.1.1 2007/05/30 04:28:25 gtkwave Exp $
  * $Log: lxt2vcd.c,v $
+ * Revision 1.1.1.1  2007/05/30 04:28:25  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
