@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2006 Tony Bybell.
+ * Copyright (c) 2006-2008 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -24,8 +24,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if !defined _MSC_VER && !defined __MINGW32__
 #include <sys/ipc.h>
 #include <sys/shm.h>
+#endif
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -277,8 +279,14 @@ return(255);
 
 
 /*
- * $Id: shmidcat.c,v 1.2 2007/08/31 22:50:47 gtkwave Exp $
+ * $Id: shmidcat.c,v 1.4 2008/02/12 23:35:42 gtkwave Exp $
  * $Log: shmidcat.c,v $
+ * Revision 1.4  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.3  2008/02/12 16:24:05  gtkwave
+ * mingw fixes
+ *
  * Revision 1.2  2007/08/31 22:50:47  gtkwave
  * update shmidcat for mingw32 compile (disabled)
  *
