@@ -37,6 +37,7 @@
 
 #include <config.h>
 #include "v2l_analyzer.h"
+#include "wave_locale.h"
 
 #undef VCD_BSEARCH_IS_PERFECT           /* bsearch is imperfect under linux, but OK under AIX */
 
@@ -476,7 +477,7 @@ for(yytext[len++]=ch;;yytext[len++]=ch)
                 yytext=(char *)realloc_2(yytext, (T_MAX_STR=T_MAX_STR*2)+1);
                 }
         ch=getch_patched();
-        if(ch<0) break;
+        if(ch<0) { free_2(varsplit); varsplit=NULL; break; }
         if((ch==':')||(ch==']'))
                 {
                 var_prevch=ch;
@@ -1103,7 +1104,11 @@ for(;;)
 			struct vcdsymbol *v=NULL;
 
 			var_prevch=0;
-			varsplit=NULL;
+			if(varsplit)
+				{
+				free_2(varsplit);
+				varsplit=NULL;
+				}
 			vtok=get_vartoken(1);
 			if(vtok>V_PORT) goto bail;
 
@@ -1654,6 +1659,11 @@ sym=(struct symbol **)calloc_2(SYMPRIME,sizeof(struct symbol *));
 printf("\nConverting VCD File '%s' to LXT file '%s'...\n\n",(vcd_handle!=stdin)?fname:"from stdin", lxname);
 build_slisthier();
 vcd_parse(linear);
+if(varsplit) 
+	{ 
+	free_2(varsplit); 
+	varsplit=NULL; 
+	}
 
 add_tail_histents();
 
@@ -1916,8 +1926,14 @@ exit(0);
 }
 
 /*
- * $Id: vcd2lxt.c,v 1.2 2007/04/20 02:08:19 gtkwave Exp $
+ * $Id: vcd2lxt.c,v 1.2 2007/06/01 21:13:41 gtkwave Exp $
  * $Log: vcd2lxt.c,v $
+ * Revision 1.2  2007/06/01 21:13:41  gtkwave
+ * regenerate configure for cygwin with proper flags, add missing files
+ *
+ * Revision 1.3  2007/04/29 06:07:28  gtkwave
+ * fixed memory leaks in vcd parser
+ *
  * Revision 1.2  2007/04/20 02:08:19  gtkwave
  * initial release
  *
