@@ -29,6 +29,8 @@
 
 #include <time.h>
 
+#include "wave_locale.h"
+
 static int flat_earth = 0;
 static int vectorize = 0;
 
@@ -394,8 +396,11 @@ return(rc);
 }
 
 /*
- * $Id: vzt2vcd.c,v 1.2 2007/04/20 02:08:19 gtkwave Exp $
+ * $Id: vzt2vcd.c,v 1.1.1.1 2007/05/30 04:28:25 gtkwave Exp $
  * $Log: vzt2vcd.c,v $
+ * Revision 1.1.1.1  2007/05/30 04:28:25  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:19  gtkwave
  * initial release
  *
