@@ -21,12 +21,15 @@
  */
 
 #include <config.h>
+
 #include "vzt_read.h"
 
 #if HAVE_GETOPT_H
 #include <getopt.h>
 #endif
 
+#include "wave_locale.h"
+
 static char *match = NULL;
 static int matchlen = 0;
 static int names_only = 0;
@@ -305,8 +308,11 @@ return(rc);
 }
 
 /*
- * $Id: vztminer.c,v 1.2 2007/04/20 02:08:19 gtkwave Exp $
+ * $Id: vztminer.c,v 1.1.1.1 2007/05/30 04:28:22 gtkwave Exp $
  * $Log: vztminer.c,v $
+ * Revision 1.1.1.1  2007/05/30 04:28:22  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:19  gtkwave
  * initial release
  *
