@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2001.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,7 +48,7 @@ GLOBALS->num_rows_hiersearch_c_1=0;
 
 if(t!=GLOBALS->treeroot)
 	{
-	maxpixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(dotdot));
+	maxpixlen=font_engine_string_measure(GLOBALS->signalfont,(gchar *)(dotdot));
 	}
 
 if(!GLOBALS->hier_grouping)
@@ -101,7 +101,7 @@ if(!GLOBALS->hier_grouping)
 	                        tmp=t2->name;
 	                        }
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
+			pixlen=font_engine_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			}
 		maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 		gtk_clist_set_row_data(cl, row,t2); 
@@ -155,7 +155,7 @@ if(!GLOBALS->hier_grouping)
 	                        }
 
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
+			pixlen=font_engine_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 			gtk_clist_set_row_data(cl, row,t2); 
 			GLOBALS->num_rows_hiersearch_c_1++;
@@ -172,7 +172,7 @@ if(!GLOBALS->hier_grouping)
                         strcpy(tmp,   "(+) ");
                         strcpy(tmp+4, t2->name);
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
-			pixlen=gdk_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
+			pixlen=font_engine_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
 			maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 			gtk_clist_set_row_data(cl, row,t2); 
 			GLOBALS->num_rows_hiersearch_c_1++;
@@ -978,8 +978,14 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: hiersearch.c,v 1.4 2007/09/12 17:26:44 gtkwave Exp $
+ * $Id: hiersearch.c,v 1.6 2008/02/12 23:35:42 gtkwave Exp $
  * $Log: hiersearch.c,v $
+ * Revision 1.6  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.5  2008/02/08 02:26:36  gtkwave
+ * anti-aliased font support add
+ *
  * Revision 1.4  2007/09/12 17:26:44  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
