@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2001-2006.
+ * Copyright (c) Tony Bybell 2001-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1113,7 +1113,7 @@ if(!GLOBALS->sync_table_offset_lxt_c_1)
 				}
 				else
 				{
-				offs += (GLOBALS->mvlfacs_lxt_c_2[facidx].len + 7)/8;
+				offs += (modlen + 7)/8; /* was offs += (GLOBALS->mvlfacs_lxt_c_2[facidx].len + 7)/8 which is wrong for integers! */
 				}
 
 			break;
@@ -2317,8 +2317,11 @@ np->numhist++;
 }
 
 /*
- * $Id: lxt.c,v 1.2 2007/08/26 21:35:41 gtkwave Exp $
+ * $Id: lxt.c,v 1.3 2008/02/22 22:08:06 gtkwave Exp $
  * $Log: lxt.c,v $
+ * Revision 1.3  2008/02/22 22:08:06  gtkwave
+ * fix of previously undetected linear lxt reader bug involving integers
+ *
  * Revision 1.2  2007/08/26 21:35:41  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
