@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2006.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,7 +74,7 @@ int i;
 char timestr[32];
 struct Global *g_old = GLOBALS;
 
-GLOBALS = (*GLOBALS->contexts)[page_num];
+set_GLOBALS((*GLOBALS->contexts)[page_num]);
 
 GLOBALS->lxt_clock_compress_to_z = g_old->lxt_clock_compress_to_z;
 GLOBALS->autoname_bundles = g_old->autoname_bundles;
@@ -97,6 +97,16 @@ gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),timestr);
 reformat_time(timestr, GLOBALS->tims.last, GLOBALS->time_dimension);
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),timestr);
 
+if(g_old->signalarea_event_box)
+	{
+	if(g_old->keypress_handler_id)
+		{
+		remove_keypress_handler(g_old->keypress_handler_id);
+		g_old->keypress_handler_id = 0;
+		}
+	GLOBALS->keypress_handler_id = install_keypress_handler();
+	}
+
 update_maxmarker_labels();
 update_basetime(GLOBALS->tims.baseline);
 
@@ -189,11 +199,12 @@ WAVE_GETOPT_CPUS
 "  -S, --script=FILE          specify GUI command script file for execution\n"
 XID_GETOPT
 INTR_GETOPT
+"  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
 "  -L, --legacy               use legacy VCD mode rather than the VCD recoder\n" 
 "  -v, --vcd                  use stdin as a VCD dumpfile\n"
 "  -V, --version              display version banner then exit\n"
 "  -h, --help                 display this help then exit\n"
-"  -x  --exit                 exit after loading trace (for loader benchmarks)\n\n"
+"  -x, --exit                 exit after loading trace (for loader benchmarks)\n\n"
 
 "VCD files and save files may be compressed with zip or gzip.\n"
 "GHW files may be compressed with gzip or bzip2.\n"
@@ -251,6 +262,7 @@ char is_vcd=0;
 char is_interactive=0;
 char is_smartsave = 0;
 char is_legacy = 0;
+char is_giga = 0;
 char fast_exit=0;
 char opt_errors_encountered=0;
 
@@ -268,6 +280,7 @@ GtkWidget *pagebuttons;
 GtkWidget *fetchbuttons;
 GtkWidget *discardbuttons;
 GtkWidget *shiftbuttons;
+GtkWidget *edgebuttons;
 GtkWidget *entry;
 GtkWidget *timebox;
 GtkWidget *panedwindow;
@@ -282,14 +295,16 @@ WAVE_LOCALE_FIX
 /* Initialize the GLOBALS structure for the first time... */ 
 if(!GLOBALS)
 	{
-	GLOBALS = initialize_globals();
+	set_GLOBALS(initialize_globals());
 	mainwindow_already_built = 0;
+
+	GLOBALS->logfiles = calloc(1, sizeof(void **)); /* calloc is deliberate! */
 	}
 	else
 	{
 	struct Global *old_g = GLOBALS;
 
-	GLOBALS = initialize_globals();
+	set_GLOBALS(initialize_globals());
 
 	GLOBALS->second_page_created = old_g->second_page_created = 1;
 
@@ -304,6 +319,9 @@ if(!GLOBALS)
 	/* busy.c */
 	GLOBALS->busycursor_busy_c_1 = old_g->busycursor_busy_c_1;
 
+	/* logfiles.c */
+	GLOBALS->logfiles = old_g->logfiles;
+
 	/* menu.c */
 	GLOBALS->item_factory_menu_c_1 = old_g->item_factory_menu_c_1;
 	GLOBALS->vcd_jmp_buf = old_g->vcd_jmp_buf;
@@ -415,7 +433,14 @@ if(!GLOBALS)
 	GLOBALS->vlist_compression_depth = old_g->vlist_compression_depth;
 	GLOBALS->zoombase = old_g->zoombase;
 	GLOBALS->splash_disable = old_g->splash_disable;
+	GLOBALS->use_pango_fonts = old_g->use_pango_fonts;
 	
+	GLOBALS->vlist_spill_to_disk = old_g->vlist_spill_to_disk;
+	GLOBALS->vlist_prepack = old_g->vlist_prepack;
+	GLOBALS->do_dynamic_treefilter = old_g->do_dynamic_treefilter;
+	GLOBALS->use_standard_clicking = old_g->use_standard_clicking;
+	GLOBALS->use_toolbutton_interface = old_g->use_toolbutton_interface;
+
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals); 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_waves, &old_g->fontname_waves);
@@ -473,11 +498,12 @@ while (1)
                 {"nomenus", 0, 0, 'M'},
                 {"dualid", 1, 0, 'D'},
                 {"interactive", 0, 0, 'I'},
+		{"giga", 0, 0, 'g'},
                 {"legacy", 0, 0, 'L'},  
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IL", long_options, &option_index);
+        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgL", long_options, &option_index);
 
         if (c == -1) break;     /* no more args */
 
@@ -672,6 +698,10 @@ while (1)
 			}
 			break;
 
+		case 'g':
+			is_giga = 1;
+			break;
+
                 case '?':
 			opt_errors_encountered=1;
                         break;
@@ -718,6 +748,11 @@ if(!GLOBALS->loaded_file_name)
 read_rc_file(override_rc);
 GLOBALS->splash_disable |= splash_disable_rc_override;
 
+if(is_giga)
+	{
+	GLOBALS->vlist_spill_to_disk = 1;
+	GLOBALS->vlist_prepack = 1;
+	}
 
 fprintf(stderr, "\n%s\n\n",WAVE_VERSION_INFO);
 
@@ -1093,150 +1128,339 @@ if(!GLOBALS->socket_xid)
 
 make_pixmaps(GLOBALS->mainwindow);
 
-
-if(!mainwindow_already_built)
-{
-main_vbox = gtk_vbox_new(FALSE, 5);
-gtk_container_border_width(GTK_CONTAINER(main_vbox), 1);
-gtk_container_add(GTK_CONTAINER(GLOBALS->mainwindow), main_vbox);
-gtk_widget_show(main_vbox);
-
-if(!GLOBALS->disable_menus)
+#ifdef WAVE_USE_GTK2
+if(GLOBALS->use_toolbutton_interface)
 	{
-	get_main_menu(GLOBALS->mainwindow, &menubar);
-	gtk_widget_show(menubar);
+	GtkWidget *tb;
+	GtkWidget *stock;
+	int tb_pos;
 
-	if(GLOBALS->force_toolbars)
+	if(!mainwindow_already_built)
 		{
-		toolhandle=gtk_handle_box_new();
-		gtk_widget_show(toolhandle);
-		gtk_container_add(GTK_CONTAINER(toolhandle), menubar);
-		gtk_box_pack_start(GTK_BOX(main_vbox), toolhandle, FALSE, TRUE, 0);
-		}
-		else
+		main_vbox = gtk_vbox_new(FALSE, 5);
+		gtk_container_border_width(GTK_CONTAINER(main_vbox), 1);
+		gtk_container_add(GTK_CONTAINER(GLOBALS->mainwindow), main_vbox);
+		gtk_widget_show(main_vbox);
+	
+		if(!GLOBALS->disable_menus)
+			{
+			get_main_menu(GLOBALS->mainwindow, &menubar);
+			gtk_widget_show(menubar);
+	
+			if(GLOBALS->force_toolbars)
+				{
+				toolhandle=gtk_handle_box_new();
+				gtk_widget_show(toolhandle);
+				gtk_container_add(GTK_CONTAINER(toolhandle), menubar);
+				gtk_box_pack_start(GTK_BOX(main_vbox), toolhandle, FALSE, TRUE, 0);
+				}
+				else
+				{
+				gtk_box_pack_start(GTK_BOX(main_vbox), menubar, FALSE, TRUE, 0);
+				}
+			}
+	
+		if(GLOBALS->force_toolbars)
+			{
+			toolhandle=gtk_handle_box_new();
+			gtk_widget_show(toolhandle);
+			gtk_container_add(GTK_CONTAINER(toolhandle), top_table);
+			}
+
+		whole_table = gtk_table_new (256, 16, FALSE);
+	
+		tb = gtk_toolbar_new();
+		top_table = tb;		/* export this as our top widget rather than a table */
+
+		gtk_toolbar_set_style(GTK_TOOLBAR(tb), GTK_TOOLBAR_ICONS);
+		tb_pos = 0;
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_CUT,
+						 "Cut Traces",
+						 NULL,
+						 GTK_SIGNAL_FUNC(menu_cut_traces),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_PASTE,
+						 "Paste Traces",
+						 NULL,
+						 GTK_SIGNAL_FUNC(menu_paste_traces),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_ZOOM_FIT,
+						 "Zoom Fit",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_fit),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_ZOOM_IN,
+						 "Zoom In",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_in),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_ZOOM_OUT,
+						 "Zoom Out",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_out),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_UNDO,
+						 "Zoom Undo",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_undo),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_GOTO_FIRST,
+						 "Zoom to Start",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_left),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_GOTO_LAST,
+						 "Zoom to End",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_zoom_right),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_GO_BACK,
+						 "Find Previous Edge",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_left_edge),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_GO_FORWARD,
+						 "Find Next Edge",
+						 NULL,
+						 GTK_SIGNAL_FUNC(service_right_edge),
+						 NULL,
+						 tb_pos++);
+		gtk_widget_show(stock);
+
+		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
+
+		entry = create_entry_box();
+		gtk_widget_show(entry);
+		gtk_toolbar_insert_widget(GTK_TOOLBAR(tb),
+                                          entry,
+                                          NULL,
+					  NULL,
+					  tb_pos++);
+
+		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
+
+		if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
+			{
+			stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
+	                                         GTK_STOCK_REFRESH,
+						 "Reload",
+						 NULL,
+						 GTK_SIGNAL_FUNC(menu_reload_waveform),
+						 NULL,
+						 tb_pos++);
+			gtk_widget_show(stock);
+
+			gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
+			}
+
+		timebox = create_time_box();
+		gtk_widget_show (timebox);
+		gtk_toolbar_insert_widget(GTK_TOOLBAR(tb),
+                                          timebox,
+                                          NULL,
+					  NULL,
+					  tb_pos++);
+
+		} /* of ...if(mainwindow_already_built) */
+	}
+	else
+#endif
+	{
+	if(!mainwindow_already_built)
 		{
-		gtk_box_pack_start(GTK_BOX(main_vbox), menubar, FALSE, TRUE, 0);
-		}
+		main_vbox = gtk_vbox_new(FALSE, 5);
+		gtk_container_border_width(GTK_CONTAINER(main_vbox), 1);
+		gtk_container_add(GTK_CONTAINER(GLOBALS->mainwindow), main_vbox);
+		gtk_widget_show(main_vbox);
+	
+		if(!GLOBALS->disable_menus)
+			{
+			get_main_menu(GLOBALS->mainwindow, &menubar);
+			gtk_widget_show(menubar);
+	
+			if(GLOBALS->force_toolbars)
+				{
+				toolhandle=gtk_handle_box_new();
+				gtk_widget_show(toolhandle);
+				gtk_container_add(GTK_CONTAINER(toolhandle), menubar);
+				gtk_box_pack_start(GTK_BOX(main_vbox), toolhandle, FALSE, TRUE, 0);
+				}
+				else
+				{
+				gtk_box_pack_start(GTK_BOX(main_vbox), menubar, FALSE, TRUE, 0);
+				}
+			}
+	
+		top_table = gtk_table_new (1, 284, FALSE);
+	
+		if(GLOBALS->force_toolbars)
+			{
+			toolhandle=gtk_handle_box_new();
+			gtk_widget_show(toolhandle);
+			gtk_container_add(GTK_CONTAINER(toolhandle), top_table);
+			}
+
+		whole_table = gtk_table_new (256, 16, FALSE);
+	
+		text1 = create_text ();
+		gtk_table_attach (GTK_TABLE (top_table), text1, 0, 141, 0, 1,
+		                      	GTK_FILL,
+		                      	GTK_FILL | GTK_SHRINK, 0, 0);
+		gtk_widget_set_usize(GTK_WIDGET(text1), 200, -1);
+		gtk_widget_show (text1);
+
+		dummy1=gtk_label_new("");
+		gtk_table_attach (GTK_TABLE (top_table), dummy1, 141, 171, 0, 1,
+		                      	GTK_FILL,
+		                      	GTK_SHRINK, 0, 0);
+		gtk_widget_show (dummy1);
+
+		zoombuttons = create_zoom_buttons ();
+		gtk_table_attach (GTK_TABLE (top_table), zoombuttons, 171, 173, 0, 1,
+		                      	GTK_FILL,
+		                      	GTK_SHRINK, 0, 0);
+		gtk_widget_show (zoombuttons);
+
+		if(!GLOBALS->use_scrollbar_only)
+			{
+			pagebuttons = create_page_buttons ();
+			gtk_table_attach (GTK_TABLE (top_table), pagebuttons, 173, 174, 0, 1,
+			                      	GTK_FILL,
+			                      	GTK_SHRINK, 0, 0);
+			gtk_widget_show (pagebuttons);
+			fetchbuttons = create_fetch_buttons ();
+			gtk_table_attach (GTK_TABLE (top_table), fetchbuttons, 174, 175, 0, 1,
+			                      	GTK_FILL,
+			                      	GTK_SHRINK, 0, 0);
+			gtk_widget_show (fetchbuttons);
+			discardbuttons = create_discard_buttons ();
+			gtk_table_attach (GTK_TABLE (top_table), discardbuttons, 175, 176, 0, 1,
+			                      	GTK_FILL,
+			                      	GTK_SHRINK, 0, 0);
+			gtk_widget_show (discardbuttons);
+		
+			shiftbuttons = create_shift_buttons ();
+			gtk_table_attach (GTK_TABLE (top_table), shiftbuttons, 176, 177, 0, 1,
+			                      	GTK_FILL,
+			                      	GTK_SHRINK, 0, 0);
+			gtk_widget_show (shiftbuttons);
+			}
+
+		edgebuttons = create_edge_buttons ();
+		gtk_table_attach (GTK_TABLE (top_table), edgebuttons, 177, 178, 0, 1,
+		                      	GTK_FILL,
+		                      	GTK_SHRINK, 0, 0);
+		gtk_widget_show (edgebuttons);
+	
+
+		dummy2=gtk_label_new("");
+		gtk_table_attach (GTK_TABLE (top_table), dummy2, 178, 215, 0, 1,
+		                      	GTK_FILL,
+		                      	GTK_SHRINK, 0, 0);
+		gtk_widget_show (dummy2);
+
+		entry = create_entry_box();
+		gtk_table_attach (GTK_TABLE (top_table), entry, 215, 216, 0, 1,
+		                      	GTK_SHRINK,
+		                      	GTK_SHRINK, 0, 0);
+		gtk_widget_show(entry);
+
+		timebox = create_time_box();
+		gtk_table_attach (GTK_TABLE (top_table), timebox, 216, 284, 0, 1,
+		                      	GTK_FILL | GTK_EXPAND,
+		                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 20, 0);
+		gtk_widget_show (timebox);
+
+		if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
+			{
+			GtkWidget *r_pixmap = gtk_pixmap_new(GLOBALS->redo_pixmap, GLOBALS->redo_mask);
+			GtkWidget *main_vbox;
+			GtkWidget *table, *table2;
+			GtkWidget *b1, *frame;
+			GtkTooltips *tooltips;
+
+			gtk_widget_show(r_pixmap);
+		
+			tooltips=gtk_tooltips_new_2();
+			gtk_tooltips_set_delay_2(tooltips,1500);
+
+			table = gtk_table_new (1, 1, FALSE);
+		
+			main_vbox = gtk_vbox_new (FALSE, 1);
+			gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
+			gtk_container_add (GTK_CONTAINER (table), main_vbox);
+	
+			frame = gtk_frame_new ("Reload ");
+			gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 0);
+	
+			gtk_widget_show (frame);
+			gtk_widget_show (main_vbox);
+
+			table2 = gtk_table_new (2, 1, FALSE);
+	
+			b1 = gtk_button_new();
+			gtk_container_add(GTK_CONTAINER(b1), r_pixmap);
+			gtk_table_attach (GTK_TABLE (table2), b1, 0, 1, 0, 1,
+			                        GTK_FILL | GTK_EXPAND,
+			                        GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
+
+			gtk_signal_connect_object (GTK_OBJECT (b1), "clicked", GTK_SIGNAL_FUNC(menu_reload_waveform), GTK_OBJECT (table2));
+			gtk_tooltips_set_tip_2(tooltips, b1, "Reload waveform", NULL);
+			gtk_widget_show(b1);
+			gtk_container_add (GTK_CONTAINER (frame), table2);
+			gtk_widget_show(table2);
+
+			gtk_table_attach (GTK_TABLE (top_table), table, 284, 285, 0, 1,
+		                      	0, 
+		                      	0, 2, 0);
+	
+			gtk_widget_show (table);
+			}
+		} /* of ...if(mainwindow_already_built) */
 	}
 
-top_table = gtk_table_new (1, 284, FALSE);
-
-if(GLOBALS->force_toolbars)
-	{
-	toolhandle=gtk_handle_box_new();
-	gtk_widget_show(toolhandle);
-	gtk_container_add(GTK_CONTAINER(toolhandle), top_table);
-	}
-
-whole_table = gtk_table_new (256, 16, FALSE);
-
-text1 = create_text ();
-gtk_table_attach (GTK_TABLE (top_table), text1, 0, 141, 0, 1,
-                      	GTK_FILL,
-                      	GTK_FILL | GTK_SHRINK, 0, 0);
-gtk_widget_set_usize(GTK_WIDGET(text1), 200, -1);
-gtk_widget_show (text1);
-
-dummy1=gtk_label_new("");
-gtk_table_attach (GTK_TABLE (top_table), dummy1, 141, 171, 0, 1,
-                      	GTK_FILL,
-                      	GTK_SHRINK, 0, 0);
-gtk_widget_show (dummy1);
-
-zoombuttons = create_zoom_buttons ();
-gtk_table_attach (GTK_TABLE (top_table), zoombuttons, 171, 173, 0, 1,
-                      	GTK_FILL,
-                      	GTK_SHRINK, 0, 0);
-gtk_widget_show (zoombuttons);
-
-if(!GLOBALS->use_scrollbar_only)
-	{
-	pagebuttons = create_page_buttons ();
-	gtk_table_attach (GTK_TABLE (top_table), pagebuttons, 173, 174, 0, 1,
-	                      	GTK_FILL,
-	                      	GTK_SHRINK, 0, 0);
-	gtk_widget_show (pagebuttons);
-	fetchbuttons = create_fetch_buttons ();
-	gtk_table_attach (GTK_TABLE (top_table), fetchbuttons, 174, 175, 0, 1,
-	                      	GTK_FILL,
-	                      	GTK_SHRINK, 0, 0);
-	gtk_widget_show (fetchbuttons);
-	discardbuttons = create_discard_buttons ();
-	gtk_table_attach (GTK_TABLE (top_table), discardbuttons, 175, 176, 0, 1,
-	                      	GTK_FILL,
-	                      	GTK_SHRINK, 0, 0);
-	gtk_widget_show (discardbuttons);
-	
-	shiftbuttons = create_shift_buttons ();
-	gtk_table_attach (GTK_TABLE (top_table), shiftbuttons, 176, 177, 0, 1,
-	                      	GTK_FILL,
-	                      	GTK_SHRINK, 0, 0);
-	gtk_widget_show (shiftbuttons);
-	}
-
-dummy2=gtk_label_new("");
-gtk_table_attach (GTK_TABLE (top_table), dummy2, 177, 215, 0, 1,
-                      	GTK_FILL,
-                      	GTK_SHRINK, 0, 0);
-gtk_widget_show (dummy2);
-
-entry = create_entry_box();
-gtk_table_attach (GTK_TABLE (top_table), entry, 215, 216, 0, 1,
-                      	GTK_SHRINK,
-                      	GTK_SHRINK, 0, 0);
-gtk_widget_show(entry);
-
-timebox = create_time_box();
-gtk_table_attach (GTK_TABLE (top_table), timebox, 216, 284, 0, 1,
-                      	GTK_FILL | GTK_EXPAND,
-                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 20, 0);
-gtk_widget_show (timebox);
-
-if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
-	{
-	GtkWidget *r_pixmap = gtk_pixmap_new(GLOBALS->redo_pixmap, GLOBALS->redo_mask);
-	GtkWidget *main_vbox;
-	GtkWidget *table, *table2;
-	GtkWidget *b1, *frame;
-	GtkTooltips *tooltips;
-
-	gtk_widget_show(r_pixmap);
-
-	tooltips=gtk_tooltips_new_2();
-	gtk_tooltips_set_delay_2(tooltips,1500);
-
-	table = gtk_table_new (1, 1, FALSE);
-
-	main_vbox = gtk_vbox_new (FALSE, 1);
-	gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
-	gtk_container_add (GTK_CONTAINER (table), main_vbox);
-	
-	frame = gtk_frame_new ("Reload ");
-	gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 0);
-	
-	gtk_widget_show (frame);
-	gtk_widget_show (main_vbox);
-
-	table2 = gtk_table_new (2, 1, FALSE);
-	
-	b1 = gtk_button_new();
-	gtk_container_add(GTK_CONTAINER(b1), r_pixmap);
-	gtk_table_attach (GTK_TABLE (table2), b1, 0, 1, 0, 1,
-	                        GTK_FILL | GTK_EXPAND,
-	                        GTK_FILL | GTK_EXPAND | GTK_SHRINK, 1, 1);
-	gtk_signal_connect_object (GTK_OBJECT (b1), "clicked", GTK_SIGNAL_FUNC(menu_reload_waveform), GTK_OBJECT (table2));
-	gtk_tooltips_set_tip_2(tooltips, b1, "Reload waveform", NULL);
-	gtk_widget_show(b1);
-	gtk_container_add (GTK_CONTAINER (frame), table2);
-	gtk_widget_show(table2);
-
-	gtk_table_attach (GTK_TABLE (top_table), table, 284, 285, 0, 1,
-                      	0, 
-                      	0, 2, 0);
-
-	gtk_widget_show (table);
-	}
-} /* of ...if(mainwindow_already_built) */
 
 GLOBALS->wavewindow = create_wavewindow();
 load_all_fonts(); /* must be done before create_signalwindow() */
@@ -1284,6 +1508,13 @@ if(GLOBALS->paned_pack_semantics)
 
 gtk_widget_show(panedwindow);
 
+if(GLOBALS->dnd_sigview)
+	{
+	dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
+	}
+dnd_setup(GLOBALS->signalarea, GLOBALS->signalarea);
+dnd_setup(GLOBALS->signalarea, GLOBALS->wavearea);
+
 #if GTK_CHECK_VERSION(2,4,0)
 if(!GLOBALS->hide_sst)
 	{
@@ -1302,6 +1533,7 @@ if(!mainwindow_already_built)
 	                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
 	}
 
+
 if(!GLOBALS->notebook)
 	{
 	GLOBALS->num_notebook_pages = 1;
@@ -1371,7 +1603,11 @@ gtk_table_attach (GTK_TABLE (whole_table), GLOBALS->notebook, 0, 16, 1, 256,
 gtk_widget_show(whole_table);
 gtk_container_add (GTK_CONTAINER (main_vbox), whole_table);
 
-update_markertime(time_trunc(GLOBALS->tims.marker));
+if(GLOBALS->tims.marker != -1)
+	{
+	if(GLOBALS->tims.marker<GLOBALS->tims.first) GLOBALS->tims.marker=GLOBALS->tims.first;
+	}
+update_markertime(GLOBALS->tims.marker);
 
 set_window_xypos(GLOBALS->initial_window_xpos, GLOBALS->initial_window_ypos);
 GLOBALS->xy_ignore_main_c_1 = 1;
@@ -1651,7 +1887,7 @@ if(GLOBALS->anno_ctx && GLOBALS->anno_ctx->browser_process)
 		}
 		else
 		{
-		shmdt(GLOBALS->anno_ctx);
+		shmdt((void *)GLOBALS->anno_ctx);
 		GLOBALS->anno_ctx = NULL;
 		}
 	}
@@ -1802,8 +2038,54 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.13 2007/09/17 19:26:46 gtkwave Exp $
+ * $Id: main.c,v 1.28 2008/04/03 16:45:06 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.28  2008/04/03 16:45:06  gtkwave
+ * removed call to time_trunc with marker setting on initialization
+ *
+ * Revision 1.27  2008/03/20 01:37:44  gtkwave
+ * fix for primary marker time on init (should be -- instead of 0 sec if not
+ * specified in a save file)
+ *
+ * Revision 1.26  2008/02/10 18:08:28  gtkwave
+ * removal of logfiles static and moved into global structure
+ *
+ * Revision 1.25  2008/02/10 01:24:00  gtkwave
+ * minor cleanups
+ *
+ * Revision 1.24  2008/01/09 22:25:55  gtkwave
+ * added toolbar spacers, increased starting mainwindow x size
+ *
+ * Revision 1.23  2008/01/09 19:20:52  gtkwave
+ * more updating to globals management (expose events cause wrong swap)
+ *
+ * Revision 1.22  2008/01/09 08:25:41  gtkwave
+ * added cut + paste buttons
+ *
+ * Revision 1.21  2008/01/09 08:07:03  gtkwave
+ * removal of explicit menu string names when unnecessary
+ *
+ * Revision 1.20  2008/01/09 04:09:11  gtkwave
+ * fix keyboard focus sighandler when multi-tabs are being used
+ *
+ * Revision 1.19  2008/01/08 23:03:35  gtkwave
+ * added toolbar using use_toolbutton_interface rc variable
+ *
+ * Revision 1.18  2008/01/05 22:25:46  gtkwave
+ * degate busy during treeview dnd as it disrupts focus; dnd cleanups
+ *
+ * Revision 1.17  2008/01/02 18:54:11  gtkwave
+ * cleaned up inconsistent punctuation on --exit option
+ *
+ * Revision 1.16  2007/12/30 04:27:39  gtkwave
+ * added edge buttons to main window
+ *
+ * Revision 1.15  2007/12/18 17:28:54  gtkwave
+ * added --giga command line option to gtkwave
+ *
+ * Revision 1.14  2007/09/23 18:33:54  gtkwave
+ * warnings cleanups from sun compile
+ *
  * Revision 1.13  2007/09/17 19:26:46  gtkwave
  * added dead context sweep code (deferred cleanup of multi-tab destroy)
  *
