@@ -28,6 +28,7 @@ GtkWidget *create_zoom_buttons(void);
 GtkWidget *create_page_buttons(void);
 GtkWidget *create_fetch_buttons(void);
 GtkWidget *create_discard_buttons(void);
+GtkWidget *create_edge_buttons(void);
 GtkWidget *create_shift_buttons(void);
 GtkWidget *create_entry_box(void);
 GtkWidget *create_time_box(void);
@@ -72,8 +73,11 @@ enum FileType {
 #endif
 
 /*
- * $Id: main.h,v 1.2 2007/08/26 21:35:42 gtkwave Exp $
+ * $Id: main.h,v 1.3 2007/12/30 04:27:39 gtkwave Exp $
  * $Log: main.h,v $
+ * Revision 1.3  2007/12/30 04:27:39  gtkwave
+ * added edge buttons to main window
+ *
  * Revision 1.2  2007/08/26 21:35:42  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
