@@ -7,6 +7,7 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include <gtk/gtk.h>
 #include <string.h>
@@ -15,12 +16,7 @@
 #include "analyzer.h"
 #include "currenttime.h"
 
-static GtkWidget *window;
-static GtkWidget *entries[26];
-static GtkSignalFunc cleanup;
-static int dirty;
 
-static TimeType shadow_markers[26];
 
 static void enter_callback(GtkWidget *widget, gpointer which)
 {
@@ -34,62 +30,64 @@ int ent_idx;
 
 ent_idx = ((int) (((long) which) & 31L)) % 26;
  
-entry=entries[ent_idx];
+entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
 if(!(len=strlen(entry_text))) goto failure;
 
-temp=unformat_time(entry_text, time_dimension);
-if((temp<tims.start)||(temp>tims.last)) goto failure;
+temp=unformat_time(entry_text, GLOBALS->time_dimension);
+if((temp<GLOBALS->tims.start)||(temp>GLOBALS->tims.last)) goto failure;
 
 for(i=0;i<26;i++)
 	{
-	if(temp==shadow_markers[i]) goto failure;
+	if(temp==GLOBALS->shadow_markers_markerbox_c_1[i]) goto failure;
 	}
 
-reformat_time(buf, temp, time_dimension);
+reformat_time(buf, temp, GLOBALS->time_dimension);
 gtk_entry_set_text (GTK_ENTRY (entry), buf);
 
-shadow_markers[ent_idx]=temp;
-dirty=1;
+GLOBALS->shadow_markers_markerbox_c_1[ent_idx]=temp;
+GLOBALS->dirty_markerbox_c_1=1;
 gtk_entry_select_region (GTK_ENTRY (entry),
 			     0, GTK_ENTRY(entry)->text_length);
 return;
 
 failure:
 modify=(TimeType *)which;
-if(shadow_markers[ent_idx]==-1)
+if(GLOBALS->shadow_markers_markerbox_c_1[ent_idx]==-1)
 	{
 	sprintf(buf,"<None>");
 	}
 	else
 	{
-	reformat_time(buf, shadow_markers[ent_idx], time_dimension);
+	reformat_time(buf, GLOBALS->shadow_markers_markerbox_c_1[ent_idx], GLOBALS->time_dimension);
 	}
 gtk_entry_set_text (GTK_ENTRY (entry), buf);
 }
 
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-if(dirty)
+if(GLOBALS->dirty_markerbox_c_1)
 	{
 	int i;
-	for(i=0;i<26;i++) named_markers[i]=shadow_markers[i];
+	for(i=0;i<26;i++) GLOBALS->named_markers[i]=GLOBALS->shadow_markers_markerbox_c_1[i];
         MaxSignalLength();
-        signalarea_configure_event(signalarea, NULL);
-        wavearea_configure_event(wavearea, NULL);
+        signalarea_configure_event(GLOBALS->signalarea, NULL);
+        wavearea_configure_event(GLOBALS->wavearea, NULL);
 	}
 
-  gtk_grab_remove(window);
-  gtk_widget_destroy(window);
+  gtk_grab_remove(GLOBALS->window_markerbox_c_4);
+  gtk_widget_destroy(GLOBALS->window_markerbox_c_4);
+  GLOBALS->window_markerbox_c_4 = NULL;
 
-  cleanup();
+  GLOBALS->cleanup_markerbox_c_4();
 }
 
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
-  gtk_grab_remove(window);
-  gtk_widget_destroy(window);
+  gtk_grab_remove(GLOBALS->window_markerbox_c_4);
+  gtk_widget_destroy(GLOBALS->window_markerbox_c_4);
+  GLOBALS->window_markerbox_c_4 = NULL;
 }
 
 void markerbox(char *title, GtkSignalFunc func)
@@ -101,17 +99,18 @@ void markerbox(char *title, GtkSignalFunc func)
     char labtitle[2]={0,0};
     int i;
 
-    cleanup=func;
-    dirty=0;
+    GLOBALS->cleanup_markerbox_c_4=func;
+    GLOBALS->dirty_markerbox_c_1=0;
 
-    for(i=0;i<26;i++) shadow_markers[i]=named_markers[i];
+    for(i=0;i<26;i++) GLOBALS->shadow_markers_markerbox_c_1[i]=GLOBALS->named_markers[i];
 
     /* create a new modal window */
-    window = gtk_window_new(disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-    gtk_grab_add(window);
-    gtk_window_set_title(GTK_WINDOW (window), title);
-    gtk_signal_connect(GTK_OBJECT (window), "delete_event",
-                       (GtkSignalFunc) destroy_callback, NULL);
+    GLOBALS->window_markerbox_c_4 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
+    install_focus_cb(GLOBALS->window_markerbox_c_4, ((char *)&GLOBALS->window_markerbox_c_4) - ((char *)GLOBALS));
+
+    gtk_grab_add(GLOBALS->window_markerbox_c_4);
+    gtk_window_set_title(GTK_WINDOW (GLOBALS->window_markerbox_c_4), title);
+    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_markerbox_c_4), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
 
     vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox);
@@ -155,17 +154,15 @@ void markerbox(char *title, GtkSignalFunc func)
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (vbox_g), label, TRUE, TRUE, 0);
 
-    entries[i]=entry = gtk_entry_new_with_max_length (48);
-    gtk_signal_connect(GTK_OBJECT(entry), "activate",
-		       GTK_SIGNAL_FUNC(enter_callback),
-		       (void *)((long) i));
-    if(shadow_markers[i]==-1)
+    GLOBALS->entries_markerbox_c_1[i]=entry = gtk_entry_new_with_max_length (48);
+    gtkwave_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(enter_callback), (void *)((long) i));
+    if(GLOBALS->shadow_markers_markerbox_c_1[i]==-1)
 	{
 	sprintf(buf,"<None>");
 	}
 	else
 	{
-	reformat_time(buf, shadow_markers[i], time_dimension);
+	reformat_time(buf, GLOBALS->shadow_markers_markerbox_c_1[i], GLOBALS->time_dimension);
 	}
 
     gtk_entry_set_text (GTK_ENTRY (entry), buf);
@@ -184,34 +181,59 @@ void markerbox(char *title, GtkSignalFunc func)
 
     button1 = gtk_button_new_with_label ("OK");
     gtk_widget_set_usize(button1, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button1), "clicked",
-			       GTK_SIGNAL_FUNC(ok_callback),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button1), "clicked", GTK_SIGNAL_FUNC(ok_callback), NULL);
     gtk_widget_show (button1);
     gtk_container_add (GTK_CONTAINER (hbox), button1);
     GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);
-    gtk_signal_connect_object (GTK_OBJECT (button1),
-                                "realize",
-                             (GtkSignalFunc) gtk_widget_grab_default,
-                             GTK_OBJECT (button1));
+    gtkwave_signal_connect_object (GTK_OBJECT (button1), "realize", (GtkSignalFunc) gtk_widget_grab_default, GTK_OBJECT (button1));
 
 
     button2 = gtk_button_new_with_label ("Cancel");
     gtk_widget_set_usize(button2, 100, -1);
-    gtk_signal_connect(GTK_OBJECT (button2), "clicked",
-			       GTK_SIGNAL_FUNC(destroy_callback),
-			       NULL);
+    gtkwave_signal_connect(GTK_OBJECT (button2), "clicked", GTK_SIGNAL_FUNC(destroy_callback), NULL);
     GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
     gtk_widget_show (button2);
     gtk_container_add (GTK_CONTAINER (hbox), button2);
 
-    gtk_container_add (GTK_CONTAINER (window), table); /* need this table to keep ok/cancel buttons from stretching! */
-    gtk_widget_show(window);
+    gtk_container_add (GTK_CONTAINER (GLOBALS->window_markerbox_c_4), table); /* need this table to keep ok/cancel buttons from stretching! */
+    gtk_widget_show(GLOBALS->window_markerbox_c_4);
 }
 
 /*
- * $Id: markerbox.c,v 1.2 2007/04/20 02:08:13 gtkwave Exp $
+ * $Id: markerbox.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
  * $Log: markerbox.c,v $
+ * Revision 1.4  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.3  2007/09/10 18:08:49  gtkwave
+ * tabs selection can swap dynamically based on external window focus
+ *
+ * Revision 1.2  2007/08/26 21:35:42  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
+ * widget destroys and teardown of file formats which use external loaders
+ * and are outside of malloc_2/free_2 control
+ *
+ * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.5  2007/08/06 03:50:47  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.4  2007/08/05 02:27:21  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
+ * Merge Complete - I hope
+ *
+ * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
+ * Merged in the main line
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:35  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:13  gtkwave
  * initial release
  *
