@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006.
+ * Copyright (c) Tony Bybell 2006-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,52 @@
 #include "color.h"
 #include "bsearch.h"
 
+/************************************************************************************************/
+
+static int determine_trace_flags(unsigned int flags, char *ch)
+{
+int pos = 0;
+
+/* [0] */
+if((flags & TR_SIGNED) != 0)
+	{
+	ch[pos++] = '+';
+	}
+
+/* [1] */
+if((flags & TR_HEX) != 0) { ch[pos++] = 'X'; }
+else if ((flags & TR_ASCII) != 0) { ch[pos++] = 'A'; }
+else if ((flags & TR_DEC) != 0) { ch[pos++] = 'D'; }  
+else if ((flags & TR_BIN) != 0) { ch[pos++] = 'B'; }  
+else if ((flags & TR_OCT) != 0) { ch[pos++] = 'O'; }  
+        
+/* [2] */
+if((flags & TR_RJUSTIFY) != 0) { ch[pos++] = 'J'; } 
+
+/* [3] */
+if((flags & TR_INVERT) != 0) { ch[pos++] = '~'; }
+
+/* [4] */
+if((flags & TR_REVERSE) != 0) { ch[pos++] = 'V'; }
+
+/* [5] */
+if((flags & (TR_ANALOG_STEP|TR_ANALOG_INTERPOLATED)) == (TR_ANALOG_STEP|TR_ANALOG_INTERPOLATED)) { ch[pos++] = '*'; } 
+else if((flags & TR_ANALOG_STEP) != 0) { ch[pos++] = 'S'; }
+else if((flags & TR_ANALOG_INTERPOLATED) != 0) { ch[pos++] = 'I'; }
+
+/* [6] */
+if((flags & TR_REAL) != 0) { ch[pos++] = 'R'; }
+
+/* [7] */
+if((flags & TR_ZEROFILL) != 0) { ch[pos++] = '0'; }
+else
+if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
+
+/* [8] (at worst case this needs 9 characters) */
+ch[pos] = 0;
+
+return(pos);
+}
 
 /************************************************************************************************/
 
@@ -33,10 +79,12 @@ int vlen=0;
 
 if(t->name)
 	{
-	len=gdk_string_measure(GLOBALS->wavefont, t->name);
+	len=font_engine_string_measure(GLOBALS->wavefont, t->name);
 
 	if((tim!=-1)&&(!(t->flags&TR_EXCLUDE)))
 		{
+                GLOBALS->shift_timebase=t->shift;
+
 		if(t->vector)
 			{
 			char *str;
@@ -46,7 +94,7 @@ if(t->name)
                         str=convert_ascii(t,v);
 			if(str)
 				{
-				vlen=gdk_string_measure(GLOBALS->wavefont,str);
+				vlen=font_engine_string_measure(GLOBALS->wavefont,str);
 				*asciivalue=str;
 				}
 				else
@@ -74,7 +122,7 @@ if(t->name)
 						str[0]=AN_STR[h_ptr->v.h_val];
 						}
 					*asciivalue=str;
-					vlen=gdk_string_measure(GLOBALS->wavefont,str);
+					vlen=font_engine_string_measure(GLOBALS->wavefont,str);
 					}
 					else
 					{
@@ -96,7 +144,7 @@ if(t->name)
 
 					if(str)
 						{
-						vlen=gdk_string_measure(GLOBALS->wavefont,str);
+						vlen=font_engine_string_measure(GLOBALS->wavefont,str);
 						*asciivalue=str;
 						}
 						else
@@ -189,8 +237,10 @@ int nmaxlen = 0, vmaxlen = 0;
 int totalmax;
 int name_charlen = 0, value_charlen = 0;
 int num_info_rows = 2;
+char *flagged_name = NULL;
 char *alternate_name = NULL;
 int fh;
+char flag_string[9];
 
 if(GLOBALS->disable_mouseover)
 	{
@@ -208,16 +258,30 @@ if(t)
 	{
 	local_trace_asciival(t, tim, &nmaxlen, &vmaxlen, &asciivalue);
 
-	name_charlen = t->name ? strlen(t->name) : 0;
 	value_charlen = asciivalue ? strlen(asciivalue) : 0;
 
+	name_charlen = t->name ? strlen(t->name) : 0;
+	if(name_charlen)
+		{
+		int len = determine_trace_flags(t->flags, flag_string);
+		flagged_name = malloc_2(name_charlen + 1 + len + 1);
+		memcpy(flagged_name, t->name, name_charlen);
+		flagged_name[name_charlen] = ' ';
+		strcpy(flagged_name+name_charlen+1, flag_string);
+		name_charlen += (len + 1);
+		}
+
 	if(name_charlen > MOUSEOVER_BREAKSIZE)
 		{
 		alternate_name = malloc_2(MOUSEOVER_BREAKSIZE + 1);
 		strcpy(alternate_name, "...");
-		strcpy(alternate_name + 3, t->name + name_charlen - (MOUSEOVER_BREAKSIZE - 3));
+		strcpy(alternate_name + 3, flagged_name + name_charlen - (MOUSEOVER_BREAKSIZE - 3));
 	
-		nmaxlen=gdk_string_measure(GLOBALS->wavefont, alternate_name);
+		nmaxlen=font_engine_string_measure(GLOBALS->wavefont, alternate_name);
+		}
+		else
+		{
+		nmaxlen=font_engine_string_measure(GLOBALS->wavefont, flagged_name);
 		}
 
 	if(value_charlen > MOUSEOVER_BREAKSIZE)
@@ -232,7 +296,7 @@ if(t)
 			{
 			memset(breakbuf, 0, MOUSEOVER_BREAKSIZE+1);
 			strncpy(breakbuf, asciivalue + (i*MOUSEOVER_BREAKSIZE), MOUSEOVER_BREAKSIZE);
-			localmax = gdk_string_measure(GLOBALS->wavefont, breakbuf);
+			localmax = font_engine_string_measure(GLOBALS->wavefont, breakbuf);
 			vmaxlen = (localmax > vmaxlen) ? localmax : vmaxlen;
 			}
 
@@ -290,11 +354,11 @@ gdk_draw_rectangle(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->mo_black_mouseover
 		1,1, 
 		GLOBALS->mo_width_mouseover_c_1-2, GLOBALS->mo_height_mouseover_c_1-2);
 
-gdk_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, fh + 2, alternate_name ? alternate_name : t->name);
+font_engine_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, fh + 2, alternate_name ? alternate_name : flagged_name);
 
 if(num_info_rows == 2)
 	{
-	if(asciivalue) gdk_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, 2*fh+2, asciivalue);
+	if(asciivalue) font_engine_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, 2*fh+2, asciivalue);
 	}
 	else
 	{
@@ -306,7 +370,7 @@ if(num_info_rows == 2)
 		{
 		memset(breakbuf, 0, MOUSEOVER_BREAKSIZE+1);
 		strncpy(breakbuf, asciivalue + (i*MOUSEOVER_BREAKSIZE), MOUSEOVER_BREAKSIZE);
-		gdk_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, ((2+i)*fh)+2, breakbuf);
+		font_engine_draw_string(GLOBALS->mo_pixmap_mouseover_c_1, GLOBALS->wavefont, GLOBALS->mo_dk_gray_mouseover_c_1, 4, ((2+i)*fh)+2, breakbuf);
 		}
 	}
 
@@ -316,12 +380,28 @@ gdk_draw_pixmap(GLOBALS->mo_area_mouseover_c_1->window, GLOBALS->mo_area_mouseov
 bot:
 if(asciivalue) { free_2(asciivalue); }
 if(alternate_name) { free_2(alternate_name); }
+if(flagged_name) { free_2(flagged_name); }
 #endif
 }
 
 /*
- * $Id: mouseover.c,v 1.3 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: mouseover.c,v 1.8 2008/04/25 21:31:10 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.8  2008/04/25 21:31:10  gtkwave
+ * added missing t->shift in mouseover time calculation
+ *
+ * Revision 1.7  2008/03/25 03:22:11  gtkwave
+ * expanded zero fill to include also a one fill (for pre-inverted nets)
+ *
+ * Revision 1.6  2008/03/24 21:50:03  gtkwave
+ * added trace flags display to mouseover window
+ *
+ * Revision 1.5  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.4  2008/02/08 02:26:36  gtkwave
+ * anti-aliased font support add
+ *
  * Revision 1.3  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
