@@ -11,7 +11,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <gtk/gtk.h>
+
 #include "rc.h"
+#include "color.h"
+#include "currenttime.h"
+#include "globals.h"
 
 #ifdef _MSC_VER
 #define strcasecmp _stricmp
@@ -795,6 +800,7 @@ static unsigned char c_blu[]={Enum_WaveColors};
 
 #define C_ARRAY_SIZE (sizeof(c_red)/sizeof(unsigned char))
 
+static GdkGC *rgb_contexts[C_ARRAY_SIZE];
 
 static int compar(const void *v1, const void *v2)
 {
@@ -802,6 +808,24 @@ return((int)strcasecmp((char *)v1, *(char **)v2));
 }
 
 
+GdkGC *get_gc_from_name(char *str)
+{
+char **match;   
+int offset, rgb;
+
+if((match=(char **)bsearch((void *)str, (void *)cnames, C_ARRAY_SIZE, sizeof(char *), compar)))
+	{
+	offset=match-cnames;
+	rgb=((int)c_red[offset]<<16)|((int)c_grn[offset]<<8)|((int)c_blu[offset]);
+
+	if(!rgb_contexts[offset]) rgb_contexts[offset] = alloc_color(GLOBALS->wavearea, rgb, GLOBALS->wavearea->style->white_gc);
+
+	return(rgb_contexts[offset]);
+	}
+
+return(NULL);
+}
+
 int get_rgb_from_name(char *str)
 {
 char **match;
@@ -829,9 +853,9 @@ if((match=(char **)bsearch((void *)str, (void *)cnames, C_ARRAY_SIZE, sizeof(cha
 			else
 			{
 			#if defined _MSC_VER || defined __MINGW32__
-			fprintf(stderr, "** gtkwave.ini (line %d): '%s' is an unknown color value; ignoring.\n", rc_line_no, str);
+			fprintf(stderr, "** gtkwave.ini (line %d): '%s' is an unknown color value; ignoring.\n", GLOBALS->rc_line_no, str);
 			#else
-			fprintf(stderr, "** .gtkwaverc (line %d): '%s' is an unknown color value; ignoring.\n", rc_line_no, str);
+			fprintf(stderr, "** .gtkwaverc (line %d): '%s' is an unknown color value; ignoring.\n", GLOBALS->rc_line_no, str);
 			#endif
 			return(~0);
 			}
@@ -843,8 +867,24 @@ if((match=(char **)bsearch((void *)str, (void *)cnames, C_ARRAY_SIZE, sizeof(cha
 }
 
 /*
- * $Id: rgb.c,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: rgb.c,v 1.3 2007/08/26 21:35:44 gtkwave Exp $
  * $Log: rgb.c,v $
+ * Revision 1.3  2007/08/26 21:35:44  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.5  2007/08/06 03:50:48  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.2  2007/07/23 23:13:08  gtkwave
+ * adds for color tags in filtered trace data
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:58  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
