@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2004
+ * Copyright (c) Tony Bybell 1999-2008
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -119,11 +119,13 @@ table = gtk_table_new (1, 16, FALSE);
 * GTK_SHRINK in the y direction */
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
 GLOBALS->text_status_c_2 = gtk_text_view_new ();
+gtk_text_view_set_editable (GTK_TEXT_VIEW(GLOBALS->text_status_c_2), FALSE);
 gtk_text_buffer_get_start_iter (gtk_text_view_get_buffer(GTK_TEXT_VIEW (GLOBALS->text_status_c_2)), &GLOBALS->iter_status_c_3);
 GLOBALS->bold_tag_status_c_3 = gtk_text_buffer_create_tag (GTK_TEXT_VIEW (GLOBALS->text_status_c_2)->buffer, "bold",
                                       "weight", PANGO_WEIGHT_BOLD, NULL);
 #else
 GLOBALS->text_status_c_2 = gtk_text_new (NULL, NULL);
+gtk_text_set_editable(GTK_TEXT(GLOBALS->text_status_c_2), FALSE);
 #endif
 gtk_table_attach (GTK_TABLE (table), GLOBALS->text_status_c_2, 0, 14, 0, 1,
 		      	GTK_FILL | GTK_EXPAND,
@@ -154,8 +156,14 @@ return(table);
 }
    
 /*
- * $Id: status.c,v 1.4 2007/09/12 19:24:45 gtkwave Exp $
+ * $Id: status.c,v 1.6 2008/02/12 23:35:42 gtkwave Exp $
  * $Log: status.c,v $
+ * Revision 1.6  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.5  2008/01/04 03:23:33  gtkwave
+ * have dormant key_press_event handler code.
+ *
  * Revision 1.4  2007/09/12 19:24:45  gtkwave
  * more ctx_swap_watchdog updates
  *
