@@ -112,7 +112,7 @@ return(*hay ? hay : NULL);
 /*
  * trap timescale overflows
  */
-static TimeType adjust(TimeType a, TimeType b)
+TimeType strace_adjust(TimeType a, TimeType b)
 {
 TimeType res=a+b;
 
@@ -437,6 +437,7 @@ void tracesearchbox(char *title, GtkSignalFunc func)
 
     entry = gtk_entry_new_with_max_length (257); /* %+256ch */
     gtkwave_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(enter_callback), s);
+    gtkwave_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(enter_callback), s);
 
     gtk_box_pack_start (GTK_BOX (small_hbox), entry, TRUE, FALSE, 0);
     gtk_widget_show (entry);
@@ -628,10 +629,10 @@ while(s)
 		h=bsearch_node(t->n.nd, basetime);
 		hp=GLOBALS->max_compare_index;
 		if((hp==&(t->n.nd->harray[1]))||(hp==&(t->n.nd->harray[0]))) return;
-		hp--;
+		if(basetime == ((*hp)->time+GLOBALS->shift_timebase)) hp--;
 		h=*hp;
 		s->his.h=h;
-		utt=adjust(h->time,GLOBALS->shift_timebase); tt=utt;
+		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt > maxbase) maxbase=tt;
 		}
 		else
@@ -644,10 +645,10 @@ while(s)
 		v=bsearch_vector(t->n.vec, basetime);
 		vp=GLOBALS->vmax_compare_index;
 		if((vp==&(t->n.vec->vectors[1]))||(vp==&(t->n.vec->vectors[0]))) return;
-		vp--;
+		if(basetime == ((*vp)->time+GLOBALS->shift_timebase)) vp--;
 		v=*vp;
 		s->his.v=v;
-		utt=adjust(v->time,GLOBALS->shift_timebase); tt=utt;
+		utt=strace_adjust(v->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt > maxbase) maxbase=tt;
 		}
 
@@ -673,7 +674,7 @@ while(s)
 		if((whichpass)||(GLOBALS->tims.marker>=0)) h=h->next;
 		if(!h) return;
 		s->his.h=h;
-		utt=adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
+		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
 		if(tt < maxbase) maxbase=tt;
 		}
 		else
@@ -687,7 +688,7 @@ while(s)
 		if((whichpass)||(GLOBALS->tims.marker>=0)) v=v->next;
 		if(!v) return;
 		s->his.v=v;
-		utt=adjust(v->time,GLOBALS->shift_timebase); tt=utt;
+		utt=strace_adjust(v->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt < maxbase) maxbase=tt;
 		}
 
@@ -706,7 +707,7 @@ while(s)
 	
 	if((!t->vector)&&(!(t->n.nd->ext)))
 		{
-		if(adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 			{
 			s->his.h=bsearch_node(t->n.nd, maxbase);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -782,7 +783,7 @@ while(s)
 
 		if(t->vector)
 			{
-			if(adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
 				s->his.v=bsearch_vector(t->n.vec, maxbase);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
@@ -791,7 +792,7 @@ while(s)
 			}
 			else
 			{
-			if(adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
 				s->his.h=bsearch_node(t->n.nd, maxbase);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -1021,7 +1022,7 @@ while(s)
 		while(h->time==h->next->time) h=h->next;
 		if((whichpass)||(notfirst)) h=h->next;
 		if(!h) return(MAX_HISTENT_TIME);
-		utt=adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
+		utt=strace_adjust(h->time,GLOBALS->shift_timebase); tt=utt;		
 		if(tt < maxbase) maxbase=tt;
 		}
 		else
@@ -1034,7 +1035,7 @@ while(s)
 		if((whichpass)||(notfirst)) v=v->next;
 		if(!v) return(MAX_HISTENT_TIME);
 		s->his.v=v;
-		utt=adjust(v->time,GLOBALS->shift_timebase); tt=utt;
+		utt=strace_adjust(v->time,GLOBALS->shift_timebase); tt=utt;
 		if(tt < maxbase) maxbase=tt;
 		}
 
@@ -1052,7 +1053,7 @@ while(s)
 	
 	if((!t->vector)&&(!(t->n.nd->ext)))
 		{
-		if(adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+		if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 			{
 			s->his.h=bsearch_node(t->n.nd, maxbase);
 			while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -1079,7 +1080,7 @@ while(s)
 
 			case ST_RISE:
 				totaltraces++;
-				if(((str[0]=='1')||(str[0]=='H'))&&(adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)) 
+				if(((str[0]=='1')||(str[0]=='H'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)) 
 					s->search_result=1;	
 				break;
 
@@ -1090,7 +1091,7 @@ while(s)
 
 			case ST_FALL:
 				totaltraces++;
-				if(((str[0]=='0')||(str[0]=='L'))&&(adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase))
+				if(((str[0]=='0')||(str[0]=='L'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase))
  					s->search_result=1;
 				break;
 
@@ -1107,7 +1108,7 @@ while(s)
 
 			case ST_ANY:
 				totaltraces++;
-				if(adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)s->search_result=1;
+				if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)s->search_result=1;
 				break;
 		
 			case ST_STRING:
@@ -1130,7 +1131,7 @@ while(s)
 
 		if(t->vector)
 			{
-			if(adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
 				s->his.v=bsearch_vector(t->n.vec, maxbase);
 				while(s->his.v->next && s->his.v->time==s->his.v->next->time) s->his.v=s->his.v->next;
@@ -1139,7 +1140,7 @@ while(s)
 			}
 			else
 			{
-			if(adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
+			if(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)!=maxbase) 
 				{
 				s->his.h=bsearch_node(t->n.nd, maxbase);
 				while(s->his.h->next && s->his.h->time==s->his.h->next->time) s->his.h=s->his.h->next;
@@ -1240,7 +1241,7 @@ while(s)
 
 			case ST_ANY:
 				totaltraces++;
-				if(adjust(s->his.v->time,GLOBALS->shift_timebase)==maxbase)
+				if(strace_adjust(s->his.v->time,GLOBALS->shift_timebase)==maxbase)
 					s->search_result=1;
 				break;
 		
@@ -1638,8 +1639,17 @@ if(GLOBALS->timearray)
 }
 
 /*
- * $Id: strace.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: strace.c,v 1.7 2007/12/31 17:11:58 gtkwave Exp $
  * $Log: strace.c,v $
+ * Revision 1.7  2007/12/31 17:11:58  gtkwave
+ * fixed backward seek bug in pattern/edge search
+ *
+ * Revision 1.6  2007/12/30 04:27:39  gtkwave
+ * added edge buttons to main window
+ *
+ * Revision 1.5  2007/12/29 20:19:33  gtkwave
+ * added dynamic string updates for entrybox in pattern search and sst
+ *
  * Revision 1.4  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
