@@ -77,6 +77,7 @@ struct item_mark_string {
 
 void strace_search(int direction);
 void strace_maketimetrace(int mode); /* 1=create, zero=delete */
+TimeType strace_adjust(TimeType a, TimeType b);
 
 void swap_strace_contexts(void);
 void delete_strace_context(void);
@@ -88,8 +89,11 @@ void delete_mprintf(void);
 #endif
 
 /*
- * $Id: strace.h,v 1.2 2007/08/26 21:35:45 gtkwave Exp $
+ * $Id: strace.h,v 1.3 2007/12/30 04:27:39 gtkwave Exp $
  * $Log: strace.h,v $
+ * Revision 1.3  2007/12/30 04:27:39  gtkwave
+ * added edge buttons to main window
+ *
  * Revision 1.2  2007/08/26 21:35:45  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
