@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef WAVE_SYMBOL_H
 #define WAVE_SYMBOL_H
 
@@ -66,7 +68,7 @@ struct symbol *symbol;
 };
 
 
-struct symbol *symfind(char *);
+struct symbol *symfind(char *, unsigned int *);
 struct symbol *symadd(char *, int);
 struct symbol *symadd_name_exists(char *name, int hv);
 int hash(char *s);
@@ -74,8 +76,8 @@ int hash(char *s);
 /* typically use zero for hashval as it doesn't matter if facs are sorted as symfind will bsearch... */
 #define symadd_name_exists_sym_exists(s, nam, hv) \
 (s)->name = (nam); \
-(s)->next=sym[(hv)]; \
-sym[(hv)]=(s);
+(s)->next=GLOBALS->sym[(hv)]; \
+GLOBALS->sym[(hv)]=(s);
 
 void facsplit(char *, int *, int *);
 int sigcmp(char *, char *);
@@ -90,14 +92,6 @@ int maketraces(char *, int);
 int parsewavline(char *, int);
 int parsewavline_lx2(char *, int);
 
-extern struct symbol **sym, **facs;
-extern char facs_are_sorted;
-extern int numfacs;
-extern int regions;
-extern struct symbol *firstnode;
-extern struct symbol *curnode;
-extern int longestname;
-extern int hashcache;
 
 /* additions to bitvec.c because of search.c/menu.c ==> formerly in analyzer.h */
 bvptr bits2vector(struct Bits *b);
@@ -116,8 +110,26 @@ void splash_sync(off_t current, off_t total);
 #endif
 
 /*
- * $Id: symbol.h,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: symbol.h,v 1.2 2007/08/26 21:35:45 gtkwave Exp $
  * $Log: symbol.h,v $
+ * Revision 1.2  2007/08/26 21:35:45  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.3  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.2  2007/08/07 03:18:55  kermin
+ * Changed to pointer based GLOBAL structure and added initialization function
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:24  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:55  gtkwave
+ * Imported sources
+ *
+ * Revision 1.3  2007/05/28 00:55:06  gtkwave
+ * added support for arrays as a first class dumpfile datatype
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
