@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tristan Gingold and Tony Bybell 2006.
+ * Copyright (c) Tristan Gingold and Tony Bybell 2006-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,6 +20,8 @@
 #include "busy.h"
 #include "debug.h"
 
+enum { VIEW_DRAG_INACTIVE, TREE_TO_VIEW_DRAG_ACTIVE, SEARCH_TO_VIEW_DRAG_ACTIVE };
+
 /* Treesearch is a pop-up window used to select signals.
    It is composed of two main areas:
    * A tree area to select the hierarchy [tree area]
@@ -36,57 +38,6 @@
 */
 enum { NAME_COLUMN, TREE_COLUMN, N_COLUMNS };
 
-/* Selection in the store model.  */
-
-
-/* Return 0 if the signal is not selected (ie filtered out).
-*/
-static int
-filter_signal (const char *name, const char *filter)
-{
-  while (1)
-    {
-      char f = *filter;
-      char n = *name;
-
-      if (f == '*')
-	{
-	  /* The most complex first!:
-	     '*' matches any number of characters.  */
-	  filter++;
-
-	  /* If '*' is the last char, then ok.  */
-	  if (*filter == 0)
-	    return 1;
-
-	  for (; *name; name++)
-	    if (filter_signal (name, filter))
-	      return 1;
-
-	  return 0;
-	}
-      else if (f == 0)
-	{
-	  /* End of filter.  */
-	  return n == 0;
-	}
-      else if (f == '?')
-	{
-	  if (n == 0)
-	    return 0;
-	}
-      else if (f != n)
-	{
-	  /* This also catch n == 0.  */
-	  return 0;
-	}
-
-      name++;
-      filter++;
-    }
-}
-
-
 /* list of autocoalesced (synthesized) filter names that need to be freed at some point) */
 
 static void free_afl(void)
@@ -548,6 +499,35 @@ gboolean filter_edit_cb (GtkWidget *widget, GdkEventKey *ev, gpointer *data)
 }
 
 
+/*
+ * for dynamic updates, simply fake the return key to the function above
+ */
+static
+void press_callback (GtkWidget *widget, gpointer *data)
+{
+GdkEventKey ev;
+
+ev.keyval = GDK_Return;
+
+filter_edit_cb (widget, &ev, data);
+}
+
+
+/*
+ * select/unselect all in treeview
+ */
+void treeview_select_all_callback(void)
+{
+GtkTreeSelection* ts = gtk_tree_view_get_selection(GTK_TREE_VIEW(GLOBALS->dnd_sigview));
+gtk_tree_selection_select_all(ts);
+}
+
+void treeview_unselect_all_callback(void)
+{
+GtkTreeSelection* ts = gtk_tree_view_get_selection(GTK_TREE_VIEW(GLOBALS->dnd_sigview));
+gtk_tree_selection_unselect_all(ts);
+}
+
 
 int treebox_is_active(void)
 {
@@ -957,7 +937,6 @@ sig_selection_foreach_preload_lx2
 static void
 action_callback(enum cb_action action)
 {
-
   GLOBALS->pre_import_treesearch_gtk2_c_1 = 0;
 
   /* once through to mass gather lx2 traces... */
@@ -1014,6 +993,7 @@ static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
   GLOBALS->is_active_treesearch_gtk2_c_6=0;
   gtk_widget_destroy(GLOBALS->window_treesearch_gtk2_c_12);
   GLOBALS->window_treesearch_gtk2_c_12 = NULL;
+  GLOBALS->dnd_sigview = NULL;
   GLOBALS->gtk2_tree_frame = NULL;
   free_afl();
 
@@ -1098,6 +1078,8 @@ do_tooltips:
     gtk_clist_set_column_auto_resize (GTK_CLIST (GLOBALS->tree_treesearch_gtk2_c_1), 0, TRUE);
     gtk_widget_show(GLOBALS->tree_treesearch_gtk2_c_1);
 
+    gtk_clist_set_use_drag_icons(GTK_CLIST (GLOBALS->tree_treesearch_gtk2_c_1), FALSE);
+
     clist=GTK_CLIST(GLOBALS->tree_treesearch_gtk2_c_1);
 
     gtkwave_signal_connect_object (GTK_OBJECT (clist), "select_row", GTK_SIGNAL_FUNC(select_row_callback), NULL);
@@ -1149,7 +1131,8 @@ do_tooltips:
 	gtk_tree_selection_set_mode (GLOBALS->sig_selection_treesearch_gtk2_c_1, GTK_SELECTION_MULTIPLE);
       }
 
-    dnd_setup(sig_view);
+    GLOBALS->dnd_sigview = sig_view;
+    dnd_setup(GLOBALS->dnd_sigview, GLOBALS->signalarea);
 
     sig_frame = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (sig_frame), 3);
@@ -1184,12 +1167,26 @@ do_tooltips:
 
     gtk_widget_show (GLOBALS->filter_entry);
 
-    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL); 
-    gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+    gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "activate", GTK_SIGNAL_FUNC(press_callback), NULL);
+    if(!GLOBALS->do_dynamic_treefilter)
+	{
+    	gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL);
+	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
 			   "Add a POSIX filter. "
 			   "'.*' matches any number of characters,"
-			   " '.' matches any character.  Hit Return to apply",
+			   " '.' matches any character.  Hit Return to apply.",
 			   NULL);
+	}
+	else
+	{
+    	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "changed", GTK_SIGNAL_FUNC(press_callback), NULL);
+	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+			   "Add a POSIX filter. "
+			   "'.*' matches any number of characters,"
+			   " '.' matches any character.",
+			   NULL);
+	}
+
 
     gtk_box_pack_start (GTK_BOX (filter_hbox), GLOBALS->filter_entry, FALSE, FALSE, 1);
 
@@ -1367,7 +1364,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 	gtk_tree_selection_set_mode (GLOBALS->sig_selection_treesearch_gtk2_c_1, GTK_SELECTION_MULTIPLE);
       }
 
-    dnd_setup(sig_view);
+    GLOBALS->dnd_sigview = sig_view;
 
     sig_frame = gtk_frame_new (NULL);
     gtk_container_border_width (GTK_CONTAINER (sig_frame), 3);
@@ -1398,12 +1395,25 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
     if(GLOBALS->filter_str_treesearch_gtk2_c_1) { gtk_entry_set_text(GTK_ENTRY(GLOBALS->filter_entry), GLOBALS->filter_str_treesearch_gtk2_c_1); }
     gtk_widget_show (GLOBALS->filter_entry);
 
-    gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL);
-    gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+    gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "activate", GTK_SIGNAL_FUNC(press_callback), NULL);
+    if(!GLOBALS->do_dynamic_treefilter)
+	{
+    	gtkwave_signal_connect(GTK_OBJECT (GLOBALS->filter_entry), "key_press_event", (GtkSignalFunc) filter_edit_cb, NULL);
+	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
 			   "Add a POSIX filter. "
 			   "'.*' matches any number of characters,"
-			   " '.' matches any character.  Hit Return to apply",
+			   " '.' matches any character.  Hit Return to apply.",
 			   NULL);
+	}
+	else
+	{
+	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->filter_entry), "changed", GTK_SIGNAL_FUNC(press_callback), NULL);
+	gtk_tooltips_set_tip_2(tooltips, GLOBALS->filter_entry,
+			   "Add a POSIX filter. "
+			   "'.*' matches any number of characters,"
+			   " '.' matches any character.",
+			   NULL);
+	}
 
     gtk_box_pack_start (GTK_BOX (filter_hbox), GLOBALS->filter_entry, FALSE, FALSE, 1);
 
@@ -1487,16 +1497,6 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
  **
  ****************************************************************/
 
-#define DRAG_TAR_NAME_0		"text/plain"
-#define DRAG_TAR_INFO_0		0
-
-#define DRAG_TAR_NAME_1		"text/uri-list"		/* not url-list */
-#define DRAG_TAR_INFO_1		1
-
-#define DRAG_TAR_NAME_2		"STRING"
-#define DRAG_TAR_INFO_2		2
-
-
 /*
  *	DND "drag_begin" handler, this is called whenever a drag starts.
  */
@@ -1508,6 +1508,17 @@ static void DNDBeginCB(
 		return;
 
 	/* Put any needed drag begin setup code here. */
+	if(!GLOBALS->dnd_state)
+		{
+		if(widget == GLOBALS->clist_search_c_3)
+			{
+			GLOBALS->tree_dnd_begin = SEARCH_TO_VIEW_DRAG_ACTIVE;
+			}
+			else
+			{
+			GLOBALS->tree_dnd_begin = TREE_TO_VIEW_DRAG_ACTIVE;
+			}
+		}
 }
 
 /*
@@ -1515,7 +1526,7 @@ static void DNDBeginCB(
  *	completed. So this function is the last one to be called in
  *	any given DND operation.
  */
-static void DNDEndCB(
+static void DNDEndCB_2(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
@@ -1527,16 +1538,28 @@ gdouble x, y;
 gint xi, yi;
 #endif
 
-if((widget == NULL) || (dc == NULL)) return;
-
 /* Put any needed drag end cleanup code here. */
 
-if(!GLOBALS->dnd_tgt_on_signalarea_treesearch_gtk2_c_1) return;
+if(GLOBALS->dnd_tgt_on_signalarea_treesearch_gtk2_c_1)
+	{
+	WAVE_GDK_GET_POINTER(GLOBALS->signalarea->window, &x, &y, &xi, &yi, &state);
+	WAVE_GDK_GET_POINTER_COPY;
 
-WAVE_GDK_GET_POINTER(GLOBALS->signalarea->window, &x, &y, &xi, &yi, &state);
-WAVE_GDK_GET_POINTER_COPY;
+	if((x<0)||(y<0)||(x>=GLOBALS->signalarea->allocation.width)||(y>=GLOBALS->signalarea->allocation.height)) return;
+	}
+else
+if(GLOBALS->dnd_tgt_on_wavearea_treesearch_gtk2_c_1)
+	{
+	WAVE_GDK_GET_POINTER(GLOBALS->wavearea->window, &x, &y, &xi, &yi, &state);
+	WAVE_GDK_GET_POINTER_COPY;
+
+	if((x<0)||(y<0)||(x>=GLOBALS->wavearea->allocation.width)||(y>=GLOBALS->wavearea->allocation.height)) return;
+	}
+else
+	{
+	return;
+	}
 
-if((x<0)||(y<0)||(x>GLOBALS->signalarea->allocation.width)||(y>GLOBALS->signalarea->allocation.height)) return;
 
 if((t=GLOBALS->traces.first))
         {       
@@ -1561,7 +1584,17 @@ if(trtarget < 0)
 		}
 		else
 		{
-		action_callback(ACTION_PREPEND);  /* prepend in this widget only ever used by this function call */
+		if(GLOBALS->tree_dnd_begin == SEARCH_TO_VIEW_DRAG_ACTIVE)
+			{
+			if(GLOBALS->window_search_c_7)
+				{
+				search_insert_callback(GLOBALS->window_search_c_7, 1 /* is prepend */);
+				}
+			}
+			else
+			{
+			action_callback(ACTION_PREPEND);  /* prepend in this widget only ever used by this function call */
+			}
 		goto dnd_import_fini;
 		}
 	}
@@ -1589,7 +1622,17 @@ if(t)
 	t->flags |= TR_HIGHLIGHT;
 	}
 
-action_callback (ACTION_INSERT);
+if(GLOBALS->tree_dnd_begin == SEARCH_TO_VIEW_DRAG_ACTIVE)
+	{
+	if(GLOBALS->window_search_c_7)
+		{
+		search_insert_callback(GLOBALS->window_search_c_7, 0 /* is insert */);
+		}
+	}
+	else
+	{
+	action_callback (ACTION_INSERT);
+	}
 
 if(t)
 	{
@@ -1601,9 +1644,40 @@ dnd_import_fini:
 MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
-
 }
 
+static void DNDEndCB(
+	GtkWidget *widget, GdkDragContext *dc, gpointer data
+)
+{
+if((widget == NULL) || (dc == NULL)) 
+	{
+	GLOBALS->tree_dnd_begin = VIEW_DRAG_INACTIVE;
+	return;
+	}
+
+if(GLOBALS->tree_dnd_begin == VIEW_DRAG_INACTIVE) return; /* to keep cut and paste in signalwindow from conflicting */
+
+if(GLOBALS->tree_dnd_requested)
+	{
+	GLOBALS->tree_dnd_requested = 0;
+
+	if(GLOBALS->is_lx2 == LXT2_IS_VLIST)
+		{
+		set_window_busy(NULL);
+		}
+	DNDEndCB_2(widget, dc, data);
+	if(GLOBALS->is_lx2 == LXT2_IS_VLIST)
+		{
+		set_window_idle(NULL);
+		}
+	}
+
+GLOBALS->tree_dnd_begin = VIEW_DRAG_INACTIVE;
+}
+
+
+
 /*
  *	DND "drag_motion" handler, this is called whenever the 
  *	pointer is dragging over the target widget.
@@ -1618,7 +1692,10 @@ static gboolean DNDDragMotionCB(
 	GdkDragAction suggested_action;
 	GtkWidget *src_widget, *tar_widget;
         if((widget == NULL) || (dc == NULL))
+		{
+                gdk_drag_status(dc, 0, t);
                 return(FALSE);
+		}
 
 	/* Get source widget and target widget. */
 	src_widget = gtk_drag_get_source_widget(dc);
@@ -1628,6 +1705,7 @@ static gboolean DNDDragMotionCB(
 	same_widget = (src_widget == tar_widget) ? TRUE : FALSE;
 
 	GLOBALS->dnd_tgt_on_signalarea_treesearch_gtk2_c_1 = (tar_widget == GLOBALS->signalarea);
+	GLOBALS->dnd_tgt_on_wavearea_treesearch_gtk2_c_1 = (tar_widget == GLOBALS->wavearea);
 
 	/* If this is the same widget, our suggested action should be
 	 * move.  For all other case we assume copy.
@@ -1676,6 +1754,7 @@ static void DNDDataRequestCB(
 	gpointer data
 )
 {
+GLOBALS->tree_dnd_requested = 1;  /* indicate that a request for data occurred... */
 }
 
 /*
@@ -1687,7 +1766,7 @@ static void DNDDataRequestCB(
  *	inputs may reflect those of the drop target so we need to check
  *	if this is the same structure or not.
  */
-static void DNDDataRecievedCB(
+static void DNDDataReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc,
 	gint x, gint y, GtkSelectionData *selection_data,
 	guint info, guint t, gpointer data
@@ -1711,7 +1790,7 @@ static void DNDDataDeleteCB(
 /***********************/
 
 
-void dnd_setup(GtkWidget *w)
+void dnd_setup(GtkWidget *src, GtkWidget *w)
 {
 	GtkWidget *win = w;
 	GtkTargetEntry target_entry[3];
@@ -1730,15 +1809,15 @@ void dnd_setup(GtkWidget *w)
 		/* Set up the list of data format types that our DND
 		 * callbacks will accept.
 		 */
-		target_entry[0].target = DRAG_TAR_NAME_0;
+		target_entry[0].target = WAVE_DRAG_TAR_NAME_0;
 		target_entry[0].flags = 0;
-		target_entry[0].info = DRAG_TAR_INFO_0;
-                target_entry[1].target = DRAG_TAR_NAME_1;
+		target_entry[0].info = WAVE_DRAG_TAR_INFO_0;
+                target_entry[1].target = WAVE_DRAG_TAR_NAME_1;
                 target_entry[1].flags = 0;
-                target_entry[1].info = DRAG_TAR_INFO_1;
-                target_entry[2].target = DRAG_TAR_NAME_2;
+                target_entry[1].info = WAVE_DRAG_TAR_INFO_1;
+                target_entry[2].target = WAVE_DRAG_TAR_NAME_2;
                 target_entry[2].flags = 0;
-                target_entry[2].info = DRAG_TAR_INFO_2;
+                target_entry[2].info = WAVE_DRAG_TAR_INFO_2;
 
 		/* Set the drag destination for this widget, using the
 		 * above target entry types, accept move's and coppies'.
@@ -1757,24 +1836,58 @@ void dnd_setup(GtkWidget *w)
 		 * to drag items off of this clist.
 		 */
 		gtk_drag_source_set(
-			w,
+			src,
 			GDK_BUTTON1_MASK | GDK_BUTTON2_MASK,
                         target_entry,
                         sizeof(target_entry) / sizeof(GtkTargetEntry),
 			GDK_ACTION_MOVE | GDK_ACTION_COPY
 		);
 		/* Set DND signals on clist. */
-		gtkwave_signal_connect(GTK_OBJECT(w), "drag_begin", GTK_SIGNAL_FUNC(DNDBeginCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(w), "drag_end", GTK_SIGNAL_FUNC(DNDEndCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(w), "drag_data_get", GTK_SIGNAL_FUNC(DNDDataRequestCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(w), "drag_data_received", GTK_SIGNAL_FUNC(DNDDataRecievedCB), win);
-                gtkwave_signal_connect(GTK_OBJECT(w), "drag_data_delete", GTK_SIGNAL_FUNC(DNDDataDeleteCB), win);
+		gtkwave_signal_connect(GTK_OBJECT(src), "drag_begin", GTK_SIGNAL_FUNC(DNDBeginCB), win);
+                gtkwave_signal_connect(GTK_OBJECT(src), "drag_end", GTK_SIGNAL_FUNC(DNDEndCB), win);
+                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_get", GTK_SIGNAL_FUNC(DNDDataRequestCB), win);
+                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_received", GTK_SIGNAL_FUNC(DNDDataReceivedCB), win);
+                gtkwave_signal_connect(GTK_OBJECT(src), "drag_data_delete", GTK_SIGNAL_FUNC(DNDDataDeleteCB), win);
 	}
 }
 
 /*
- * $Id: treesearch_gtk2.c,v 1.4 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: treesearch_gtk2.c,v 1.15 2008/05/11 03:05:25 gtkwave Exp $
  * $Log: treesearch_gtk2.c,v $
+ * Revision 1.15  2008/05/11 03:05:25  gtkwave
+ * add gating flag on dnd data request so moving in/out of search window
+ * doesn't cause spurious insert ops into the signal/wavewindow
+ *
+ * Revision 1.14  2008/05/06 19:37:55  gtkwave
+ * DND tweaking for drag status
+ *
+ * Revision 1.13  2008/05/05 19:27:06  gtkwave
+ * support for DND from regex search window to sig/waveareas
+ *
+ * Revision 1.12  2008/02/12 23:35:42  gtkwave
+ * preparing for 3.1.5 revision bump
+ *
+ * Revision 1.11  2008/01/13 19:16:54  gtkwave
+ * add busy on vcd_recoder dnd (not normally activated)
+ *
+ * Revision 1.10  2008/01/08 04:01:12  gtkwave
+ * more accelerator key ergonomic updates
+ *
+ * Revision 1.9  2008/01/05 22:25:46  gtkwave
+ * degate busy during treeview dnd as it disrupts focus; dnd cleanups
+ *
+ * Revision 1.8  2008/01/03 21:55:45  gtkwave
+ * various cleanups
+ *
+ * Revision 1.7  2008/01/03 05:02:14  gtkwave
+ * added dnd into wavewindow for both click modes
+ *
+ * Revision 1.6  2008/01/03 00:09:17  gtkwave
+ * preliminary dnd support for use_standard_clicking mode
+ *
+ * Revision 1.5  2007/12/29 20:19:33  gtkwave
+ * added dynamic string updates for entrybox in pattern search and sst
+ *
  * Revision 1.4  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
