@@ -12,6 +12,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "wave_locale.h"
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -87,12 +89,10 @@ if(split_point < 0)
 
 mainwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title(GTK_WINDOW(mainwindow), "TwinWave Initializing");
-gtk_widget_set_usize(GTK_WIDGET(mainwindow), 800, 640);
+gtk_widget_set_usize(GTK_WIDGET(mainwindow), 820, 800);
 gtk_widget_show(mainwindow);
 
-gtk_signal_connect(GTK_OBJECT(mainwindow), "destroy",
-	GTK_SIGNAL_FUNC(quit_callback),
-        "WM destroy");
+gtk_signal_connect(GTK_OBJECT(mainwindow), "destroy", GTK_SIGNAL_FUNC(quit_callback), "WM destroy");
 
 
 xsocket[0] = gtk_socket_new ();
@@ -100,9 +100,7 @@ xsocket[1] = gtk_socket_new ();
 gtk_widget_show (xsocket[0]);
 gtk_widget_show (xsocket[1]);
 
-gtk_signal_connect(GTK_OBJECT(xsocket[0]), "plug-removed",
-	GTK_SIGNAL_FUNC(plug_removed),
-        NULL);
+gtk_signal_connect(GTK_OBJECT(xsocket[0]), "plug-removed", GTK_SIGNAL_FUNC(plug_removed), NULL);
 
 main_vbox = gtk_vbox_new(FALSE, 5);
 gtk_container_border_width(GTK_CONTAINER(main_vbox), 1);
@@ -115,9 +113,7 @@ gtk_box_pack_start (GTK_BOX (main_vbox), vpan, TRUE, TRUE, 1);
 
 gtk_paned_pack1 (GTK_PANED (vpan), xsocket[0], TRUE, FALSE);
 
-gtk_signal_connect(GTK_OBJECT(xsocket[1]), "plug-removed",
-	GTK_SIGNAL_FUNC(plug_removed),
-        NULL);
+gtk_signal_connect(GTK_OBJECT(xsocket[1]), "plug-removed", GTK_SIGNAL_FUNC(plug_removed), NULL);
 
 gtk_paned_pack2 (GTK_PANED (vpan), xsocket[1], TRUE, FALSE);
 
@@ -258,8 +254,20 @@ return(255);
 #endif
 
 /*
- * $Id: twinwave.c,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: twinwave.c,v 1.3 2007/09/12 17:26:45 gtkwave Exp $
  * $Log: twinwave.c,v $
+ * Revision 1.3  2007/09/12 17:26:45  gtkwave
+ * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
+ *
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.1  2007/08/26 19:05:35  gtkwave
+ * usize update to handle SST in GTK >= 2.4 in dual mode
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:22  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
