@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2007.
+ * Copyright (c) Tony Bybell 1999-2008.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -116,8 +116,11 @@ static char *tokens[]={ "var", "end", "scope", "upscope",
 
 /*
  * histent structs are NEVER freed so this is OK..
+ * (we are allocating as many entries that fit in 64k minus the size of the two
+ * bookkeeping void* pointers found in the malloc_2/free_2 routines in
+ * debug.c)
  */
-#define VCD_HISTENT_GRANULARITY 100
+#define VCD_HISTENT_GRANULARITY ( ( (64*1024)-(2*sizeof(void *)) ) / sizeof(HistEnt) )
 
 struct HistEnt *histent_calloc(void)
 {
@@ -1752,7 +1755,11 @@ switch(ch)
 		if(regadd) { time*=(GLOBALS->time_scale); }
 	
 		if(
+#ifndef TRACK_AND_HOLD_FIX
 		  (n->curr->v.h_vector&&vector&&(*(double *)n->curr->v.h_vector!=*(double *)vector))
+#else
+		  (1)
+#endif
 			||(time==GLOBALS->start_time_vcd_c_1)
 			||(!n->curr->v.h_vector)
 			||(GLOBALS->vcd_preserve_glitches)
@@ -2416,8 +2423,14 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
+ * $Id: vcd.c,v 1.4 2008/01/22 20:11:47 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.4  2008/01/22 20:11:47  gtkwave
+ * track and hold experimentation
+ *
+ * Revision 1.3  2007/09/23 18:33:55  gtkwave
+ * warnings cleanups from sun compile
+ *
  * Revision 1.2  2007/08/26 21:35:46  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
