@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef VCD_H
 #define VCD_H
 
@@ -22,6 +24,7 @@
 #define ftello ftell
 #endif
 
+#include <setjmp.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -35,6 +38,16 @@
 #define VCD_BSIZ 32768	/* size of getch() emulation buffer--this val should be ok */
 #define VCD_INDEXSIZ  (8 * 1024 * 1024)
 
+#define vcd_exit(x) \
+	if(GLOBALS->vcd_jmp_buf) \
+		{ \
+		longjmp(*(GLOBALS->vcd_jmp_buf), x); \
+		} \
+		else \
+		{ \
+		exit(x); \
+		}
+
 enum VCDName_ByteSubstitutions { VCDNAM_NULL=0, VCDNAM_HIERSORT, VCDNAM_ESCAPE };
 
 /* fix for contrib/rtlbrowse */
@@ -94,22 +107,8 @@ struct vcdsymbol *sym;
 TimeType last_event_time;    /* make +1 == 0 if there's not an event there too */
 };
 
-extern int splash_disable;
 
-extern int vcd_warning_filesize;
-extern char autocoalesce;
-extern char autocoalesce_reversal;
-extern int vcd_explicit_zero_subscripts;  /* 0=yes, -1=no */
-extern char vcd_preserve_glitches;
-extern char convert_to_reals;
-extern char atomic_vectors;
-extern char make_vcd_save_file;
-extern FILE *vcd_save_handle;
 
-extern struct slist *slistroot, *slistcurr;     
-extern char *slisthier;     
-extern int slisthier_len;  
-extern char vcd_hier_delimeter[2];
 
 char *build_slisthier(void);
 void append_vcd_slisthier(char *str);
@@ -129,8 +128,23 @@ int vcd_keyword_code(const char *s, unsigned int len);
 #endif
 
 /*
- * $Id: vcd.h,v 1.2 2007/04/20 02:08:17 gtkwave Exp $
+ * $Id: vcd.h,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
  * $Log: vcd.h,v $
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.3  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.2  2007/08/24 21:23:55  gtkwave
+ * use setjump + potential backout ctx to "harden" vcd reload error recovery
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:28  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:30  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:17  gtkwave
  * initial release
  *
