@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef VCD_SAVER_H
 #define VCD_SAVER_H
 
@@ -25,8 +27,20 @@ extern char *output_hier(char *name);
 #endif
 
 /*
- * $Id: vcd_saver.h,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: vcd_saver.h,v 1.2 2007/08/26 21:35:46 gtkwave Exp $
  * $Log: vcd_saver.h,v $
+ * Revision 1.2  2007/08/26 21:35:46  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:28  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:50  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
