@@ -14,8 +14,10 @@
 #include <alloca.h>
 #elif defined(__GNUC__)
 #ifndef __MINGW32__
+#ifndef alloca
 #define alloca __builtin_alloca
 #endif
+#endif
 #elif defined(_MSC_VER)
 #include <malloc.h>
 #define alloca _alloca
@@ -24,8 +26,18 @@
 #endif 
 
 /*
- * $Id: wavealloca.h,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: wavealloca.h,v 1.2 2007/08/26 21:35:50 gtkwave Exp $
  * $Log: wavealloca.h,v $
+ * Revision 1.2  2007/08/26 21:35:50  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.1  2007/08/06 03:50:50  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:29  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
